Module api_format

Module api_format 

Module containing serializers for API format (numeric enums)

Functions

serialize_enum
Serialize an enum to its numeric value for the API
serialize_option_enum
Serialize an optional enum to its numeric value for the API
serialize_vec_enum
Serialize a vector of enums to their numeric values for the API