pub enum ChildrenStatusPreference {
OpenToAll,
No,
Yes,
}Variants
Implementations
Sourceimpl ChildrenStatusPreference
impl ChildrenStatusPreference
Sourcepub fn to_value(&self) -> Option<ChildrenStatusValue>
pub fn to_value(&self) -> Option<ChildrenStatusValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: ChildrenStatusValue) -> Self
pub fn from_value(value: ChildrenStatusValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<ChildrenStatusProfile>
pub fn into_profile(self) -> Option<ChildrenStatusProfile>
Convert this preference value into a profile variant when possible.