pub enum ChildrenStatusProfile {
PreferNotToSay,
No,
Yes,
}Variants
Implementations
Sourceimpl ChildrenStatusProfile
impl ChildrenStatusProfile
Sourcepub fn to_value(&self) -> Option<ChildrenStatusValue>
pub fn to_value(&self) -> Option<ChildrenStatusValue>
Returns the base value for this profile option, if one exists.
Sourcepub fn from_value(value: ChildrenStatusValue) -> Self
pub fn from_value(value: ChildrenStatusValue) -> Self
Construct a profile value from a shared base value.
Sourcepub fn into_preference(self) -> Option<ChildrenStatusPreference>
pub fn into_preference(self) -> Option<ChildrenStatusPreference>
Convert this profile value into a preference variant when possible.