pub enum DatingIntentionPreference {
OpenToAll,
LifePartner,
LongTermRelationship,
LongTermOpenToShort,
ShortTermOpenToLong,
ShortTermRelationship,
FiguringOutTheirDatingGoals,
}Variants
OpenToAll
LifePartner
LongTermRelationship
LongTermOpenToShort
ShortTermOpenToLong
ShortTermRelationship
FiguringOutTheirDatingGoals
Implementations
Sourceimpl DatingIntentionPreference
impl DatingIntentionPreference
Sourcepub fn to_value(&self) -> Option<DatingIntentionValue>
pub fn to_value(&self) -> Option<DatingIntentionValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: DatingIntentionValue) -> Self
pub fn from_value(value: DatingIntentionValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<DatingIntentionProfile>
pub fn into_profile(self) -> Option<DatingIntentionProfile>
Convert this preference value into a profile variant when possible.