pub enum DatingIntentionProfile {
PreferNotToSay,
LifePartner,
LongTermRelationship,
LongTermOpenToShort,
ShortTermOpenToLong,
ShortTermRelationship,
FiguringOutTheirDatingGoals,
}Variants
PreferNotToSay
LifePartner
LongTermRelationship
LongTermOpenToShort
ShortTermOpenToLong
ShortTermRelationship
FiguringOutTheirDatingGoals
Implementations
Sourceimpl DatingIntentionProfile
impl DatingIntentionProfile
Sourcepub fn to_value(&self) -> Option<DatingIntentionValue>
pub fn to_value(&self) -> Option<DatingIntentionValue>
Returns the base value for this profile option, if one exists.
Sourcepub fn from_value(value: DatingIntentionValue) -> Self
pub fn from_value(value: DatingIntentionValue) -> Self
Construct a profile value from a shared base value.
Sourcepub fn into_preference(self) -> Option<DatingIntentionPreference>
pub fn into_preference(self) -> Option<DatingIntentionPreference>
Convert this profile value into a preference variant when possible.