pub enum DrinkingStatusPreference {
OpenToAll,
No,
Yes,
Sometimes,
}Variants
Implementations
Sourceimpl DrinkingStatusPreference
impl DrinkingStatusPreference
Sourcepub fn to_value(&self) -> Option<DrinkingStatusValue>
pub fn to_value(&self) -> Option<DrinkingStatusValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: DrinkingStatusValue) -> Self
pub fn from_value(value: DrinkingStatusValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<DrinkingStatusProfile>
pub fn into_profile(self) -> Option<DrinkingStatusProfile>
Convert this preference value into a profile variant when possible.