pub enum DrinkingStatusProfile {
PreferNotToSay,
No,
Yes,
Sometimes,
}Variants
Implementations
Sourceimpl DrinkingStatusProfile
impl DrinkingStatusProfile
Sourcepub fn to_value(&self) -> Option<DrinkingStatusValue>
pub fn to_value(&self) -> Option<DrinkingStatusValue>
Returns the base value for this profile option, if one exists.
Sourcepub fn from_value(value: DrinkingStatusValue) -> Self
pub fn from_value(value: DrinkingStatusValue) -> Self
Construct a profile value from a shared base value.
Sourcepub fn into_preference(self) -> Option<DrinkingStatusPreference>
pub fn into_preference(self) -> Option<DrinkingStatusPreference>
Convert this profile value into a preference variant when possible.