pub enum DrugStatusPreference {
OpenToAll,
No,
Yes,
Sometimes,
}Variants
Implementations
Sourceimpl DrugStatusPreference
impl DrugStatusPreference
Sourcepub fn to_value(&self) -> Option<DrugStatusValue>
pub fn to_value(&self) -> Option<DrugStatusValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: DrugStatusValue) -> Self
pub fn from_value(value: DrugStatusValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<DrugStatusProfile>
pub fn into_profile(self) -> Option<DrugStatusProfile>
Convert this preference value into a profile variant when possible.