pub enum DrugStatusProfile {
PreferNotToSay,
No,
Yes,
Sometimes,
}Variants
Implementations
Sourceimpl DrugStatusProfile
impl DrugStatusProfile
Sourcepub fn to_value(&self) -> Option<DrugStatusValue>
pub fn to_value(&self) -> Option<DrugStatusValue>
Returns the base value for this profile option, if one exists.
Sourcepub fn from_value(value: DrugStatusValue) -> Self
pub fn from_value(value: DrugStatusValue) -> Self
Construct a profile value from a shared base value.
Sourcepub fn into_preference(self) -> Option<DrugStatusPreference>
pub fn into_preference(self) -> Option<DrugStatusPreference>
Convert this profile value into a preference variant when possible.