pub enum EducationAttainedPreference {
OpenToAll,
HighSchool,
TradeSchool,
InCollege,
Undergraduate,
InGradSchool,
Graduate,
}Variants
Implementations
Sourceimpl EducationAttainedPreference
impl EducationAttainedPreference
Sourcepub fn to_value(&self) -> Option<EducationAttainedValue>
pub fn to_value(&self) -> Option<EducationAttainedValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: EducationAttainedValue) -> Self
pub fn from_value(value: EducationAttainedValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<EducationAttainedProfile>
pub fn into_profile(self) -> Option<EducationAttainedProfile>
Convert this preference value into a profile variant when possible.