pub enum EthnicityPreference {
OpenToAll,
AmericanIndian,
BlackAfrican,
EastAsian,
Hispanic,
MiddleEastern,
PacificIslander,
SouthAsian,
White,
Other,
}Variants
OpenToAll
AmericanIndian
BlackAfrican
EastAsian
Hispanic
MiddleEastern
PacificIslander
SouthAsian
White
Other
Implementations
Sourceimpl EthnicityPreference
impl EthnicityPreference
Sourcepub fn to_value(&self) -> Option<EthnicityValue>
pub fn to_value(&self) -> Option<EthnicityValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: EthnicityValue) -> Self
pub fn from_value(value: EthnicityValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<EthnicityProfile>
pub fn into_profile(self) -> Option<EthnicityProfile>
Convert this preference value into a profile variant when possible.