pub enum MarijuanaStatusPreference {
OpenToAll,
No,
Yes,
Sometimes,
NoPreference,
}Variants
Implementations
Sourceimpl MarijuanaStatusPreference
impl MarijuanaStatusPreference
Sourcepub fn to_value(&self) -> Option<MarijuanaStatusValue>
pub fn to_value(&self) -> Option<MarijuanaStatusValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: MarijuanaStatusValue) -> Self
pub fn from_value(value: MarijuanaStatusValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<MarijuanaStatusProfile>
pub fn into_profile(self) -> Option<MarijuanaStatusProfile>
Convert this preference value into a profile variant when possible.