pub enum MarijuanaStatusProfile {
PreferNotToSay,
No,
Yes,
Sometimes,
NoPreference,
}Variants
Implementations
Sourceimpl MarijuanaStatusProfile
impl MarijuanaStatusProfile
Sourcepub fn to_value(&self) -> Option<MarijuanaStatusValue>
pub fn to_value(&self) -> Option<MarijuanaStatusValue>
Returns the base value for this profile option, if one exists.
Sourcepub fn from_value(value: MarijuanaStatusValue) -> Self
pub fn from_value(value: MarijuanaStatusValue) -> Self
Construct a profile value from a shared base value.
Sourcepub fn into_preference(self) -> Option<MarijuanaStatusPreference>
pub fn into_preference(self) -> Option<MarijuanaStatusPreference>
Convert this profile value into a preference variant when possible.