pub enum PoliticsPreference {
OpenToAll,
Liberal,
Moderate,
Conservative,
NotPolitical,
Other,
}Variants
Implementations
Sourceimpl PoliticsPreference
impl PoliticsPreference
Sourcepub fn to_value(&self) -> Option<PoliticsValue>
pub fn to_value(&self) -> Option<PoliticsValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: PoliticsValue) -> Self
pub fn from_value(value: PoliticsValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<PoliticsProfile>
pub fn into_profile(self) -> Option<PoliticsProfile>
Convert this preference value into a profile variant when possible.