pub enum PoliticsProfile {
PreferNotToSay,
Liberal,
Moderate,
Conservative,
NotPolitical,
Other,
}Variants
Implementations
Sourceimpl PoliticsProfile
impl PoliticsProfile
Sourcepub fn to_value(&self) -> Option<PoliticsValue>
pub fn to_value(&self) -> Option<PoliticsValue>
Returns the base value for this profile option, if one exists.
Sourcepub fn from_value(value: PoliticsValue) -> Self
pub fn from_value(value: PoliticsValue) -> Self
Construct a profile value from a shared base value.
Sourcepub fn into_preference(self) -> Option<PoliticsPreference>
pub fn into_preference(self) -> Option<PoliticsPreference>
Convert this profile value into a preference variant when possible.