pub enum RelationshipTypePreference {
OpenToAll,
Monogamy,
EthicalNonMonogamy,
FiguringOutTheirRelationshipType,
}Variants
Implementations
Sourceimpl RelationshipTypePreference
impl RelationshipTypePreference
Sourcepub fn to_value(&self) -> Option<RelationshipTypeValue>
pub fn to_value(&self) -> Option<RelationshipTypeValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: RelationshipTypeValue) -> Self
pub fn from_value(value: RelationshipTypeValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<RelationshipTypeProfile>
pub fn into_profile(self) -> Option<RelationshipTypeProfile>
Convert this preference value into a profile variant when possible.