pub enum RelationshipTypeProfile {
PreferNotToSay,
Monogamy,
EthicalNonMonogamy,
FiguringOutTheirRelationshipType,
}Variants
Implementations
Sourceimpl RelationshipTypeProfile
impl RelationshipTypeProfile
Sourcepub fn to_value(&self) -> Option<RelationshipTypeValue>
pub fn to_value(&self) -> Option<RelationshipTypeValue>
Returns the base value for this profile option, if one exists.
Sourcepub fn from_value(value: RelationshipTypeValue) -> Self
pub fn from_value(value: RelationshipTypeValue) -> Self
Construct a profile value from a shared base value.
Sourcepub fn into_preference(self) -> Option<RelationshipTypePreference>
pub fn into_preference(self) -> Option<RelationshipTypePreference>
Convert this profile value into a preference variant when possible.