pub enum ReligionPreference {
OpenToAll,
Spiritual,
Catholic,
Christian,
Hindu,
Jewish,
Muslim,
Buddhist,
Agnostic,
Atheist,
Other,
Sikh,
}Variants
Implementations
Sourceimpl ReligionPreference
impl ReligionPreference
Sourcepub fn to_value(&self) -> Option<ReligionValue>
pub fn to_value(&self) -> Option<ReligionValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: ReligionValue) -> Self
pub fn from_value(value: ReligionValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<ReligionProfile>
pub fn into_profile(self) -> Option<ReligionProfile>
Convert this preference value into a profile variant when possible.