pub enum ReligionProfile {
PreferNotToSay,
Spiritual,
Catholic,
Christian,
Hindu,
Jewish,
Muslim,
Buddhist,
Agnostic,
Atheist,
Other,
Sikh,
}Variants
PreferNotToSay
Spiritual
Catholic
Christian
Hindu
Jewish
Muslim
Buddhist
Agnostic
Atheist
Other
Sikh
Implementations
Sourceimpl ReligionProfile
impl ReligionProfile
Sourcepub fn to_value(&self) -> Option<ReligionValue>
pub fn to_value(&self) -> Option<ReligionValue>
Returns the base value for this profile option, if one exists.
Sourcepub fn from_value(value: ReligionValue) -> Self
pub fn from_value(value: ReligionValue) -> Self
Construct a profile value from a shared base value.
Sourcepub fn into_preference(self) -> Option<ReligionPreference>
pub fn into_preference(self) -> Option<ReligionPreference>
Convert this profile value into a preference variant when possible.