pub enum SmokingStatusPreference {
OpenToAll,
No,
Yes,
Sometimes,
}Variants
Implementations
Sourceimpl SmokingStatusPreference
impl SmokingStatusPreference
Sourcepub fn to_value(&self) -> Option<SmokingStatusValue>
pub fn to_value(&self) -> Option<SmokingStatusValue>
Returns the base value for this preference option, if one exists.
Sourcepub fn from_value(value: SmokingStatusValue) -> Self
pub fn from_value(value: SmokingStatusValue) -> Self
Construct a preference value from a shared base value.
Sourcepub fn into_profile(self) -> Option<SmokingStatusProfile>
pub fn into_profile(self) -> Option<SmokingStatusProfile>
Convert this preference value into a profile variant when possible.