pub enum SmokingStatusProfile {
PreferNotToSay,
No,
Yes,
Sometimes,
}Variants
Implementations
Sourceimpl SmokingStatusProfile
impl SmokingStatusProfile
Sourcepub fn to_value(&self) -> Option<SmokingStatusValue>
pub fn to_value(&self) -> Option<SmokingStatusValue>
Returns the base value for this profile option, if one exists.
Sourcepub fn from_value(value: SmokingStatusValue) -> Self
pub fn from_value(value: SmokingStatusValue) -> Self
Construct a profile value from a shared base value.
Sourcepub fn into_preference(self) -> Option<SmokingStatusPreference>
pub fn into_preference(self) -> Option<SmokingStatusPreference>
Convert this profile value into a preference variant when possible.