pub struct ActivePill {
pub pill_type: String,
pub permission: String,
pub id: String,
}Fields
pill_type: Stringpermission: Stringid: StringTrait Implementations
Sourceimpl Clone for ActivePill
impl Clone for ActivePill
Sourcefn clone(&self) -> ActivePill
fn clone(&self) -> ActivePill
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActivePill
impl Debug for ActivePill
Sourceimpl<'de> Deserialize<'de> for ActivePill
impl<'de> Deserialize<'de> for ActivePill
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActivePill
impl JsonSchema for ActivePill
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActivePill
impl RefUnwindSafe for ActivePill
impl Send for ActivePill
impl Sync for ActivePill
impl Unpin for ActivePill
impl UnsafeUnpin for ActivePill
impl UnwindSafe for ActivePill