pub struct AnswerContentPayload {
pub position: i32,
pub question_id: String,
pub text_answer: Option<Value>,
pub voice_answer: Option<VoiceAnswerPayload>,
}Fields
position: i32question_id: Stringtext_answer: Option<Value>voice_answer: Option<VoiceAnswerPayload>Trait Implementations
Sourceimpl Clone for AnswerContentPayload
impl Clone for AnswerContentPayload
Sourcefn clone(&self) -> AnswerContentPayload
fn clone(&self) -> AnswerContentPayload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnswerContentPayload
impl Debug for AnswerContentPayload
Sourceimpl<'de> Deserialize<'de> for AnswerContentPayload
impl<'de> Deserialize<'de> for AnswerContentPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnswerContentPayload
impl JsonSchema for AnswerContentPayload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AnswerContentPayload
impl RefUnwindSafe for AnswerContentPayload
impl Send for AnswerContentPayload
impl Sync for AnswerContentPayload
impl Unpin for AnswerContentPayload
impl UnsafeUnpin for AnswerContentPayload
impl UnwindSafe for AnswerContentPayload