pub struct AuthSettings {
pub apple_authed: bool,
pub facebook_authed: bool,
pub google_authed: bool,
pub sms_authed: bool,
}Fields
apple_authed: boolfacebook_authed: boolgoogle_authed: boolsms_authed: boolTrait Implementations
Sourceimpl Clone for AuthSettings
impl Clone for AuthSettings
Sourcefn clone(&self) -> AuthSettings
fn clone(&self) -> AuthSettings
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthSettings
impl Debug for AuthSettings
Sourceimpl<'de> Deserialize<'de> for AuthSettings
impl<'de> Deserialize<'de> for AuthSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuthSettings
impl JsonSchema for AuthSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuthSettings
impl RefUnwindSafe for AuthSettings
impl Send for AuthSettings
impl Sync for AuthSettings
impl Unpin for AuthSettings
impl UnsafeUnpin for AuthSettings
impl UnwindSafe for AuthSettings