pub struct ConnectionContentItem {
pub prompt: Option<ConnectionPrompt>,
pub photo: Option<PhotoAsset>,
pub video: Option<ConnectionVideo>,
pub comment: Option<String>,
}Fields
prompt: Option<ConnectionPrompt>photo: Option<PhotoAsset>video: Option<ConnectionVideo>comment: Option<String>Trait Implementations
Sourceimpl Clone for ConnectionContentItem
impl Clone for ConnectionContentItem
Sourcefn clone(&self) -> ConnectionContentItem
fn clone(&self) -> ConnectionContentItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectionContentItem
impl Debug for ConnectionContentItem
Sourceimpl<'de> Deserialize<'de> for ConnectionContentItem
impl<'de> Deserialize<'de> for ConnectionContentItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConnectionContentItem
impl JsonSchema for ConnectionContentItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConnectionContentItem
impl RefUnwindSafe for ConnectionContentItem
impl Send for ConnectionContentItem
impl Sync for ConnectionContentItem
impl Unpin for ConnectionContentItem
impl UnsafeUnpin for ConnectionContentItem
impl UnwindSafe for ConnectionContentItem