pub struct ConnectionDetailApi {
pub connection: ConnectionItem,
pub show_match_note: Option<bool>,
}Fields
connection: ConnectionItemshow_match_note: Option<bool>Trait Implementations
Sourceimpl Clone for ConnectionDetailApi
impl Clone for ConnectionDetailApi
Sourcefn clone(&self) -> ConnectionDetailApi
fn clone(&self) -> ConnectionDetailApi
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectionDetailApi
impl Debug for ConnectionDetailApi
Sourceimpl<'de> Deserialize<'de> for ConnectionDetailApi
impl<'de> Deserialize<'de> for ConnectionDetailApi
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConnectionDetailApi
impl JsonSchema for ConnectionDetailApi
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConnectionDetailApi
impl RefUnwindSafe for ConnectionDetailApi
impl Send for ConnectionDetailApi
impl Sync for ConnectionDetailApi
impl Unpin for ConnectionDetailApi
impl UnsafeUnpin for ConnectionDetailApi
impl UnwindSafe for ConnectionDetailApi