pub struct ConnectionItem {
pub initiator_id: String,
pub subject_id: String,
pub sent_content: Vec<ConnectionContentItem>,
pub sent_time: Option<String>,
pub received_time: Option<String>,
pub source: String,
pub initiated_with: String,
pub social_media_exchanged_timestamp: Option<String>,
pub is_hidden: bool,
}Fields
initiator_id: Stringsubject_id: Stringsent_content: Vec<ConnectionContentItem>sent_time: Option<String>received_time: Option<String>source: Stringinitiated_with: StringTrait Implementations
Sourceimpl Clone for ConnectionItem
impl Clone for ConnectionItem
Sourcefn clone(&self) -> ConnectionItem
fn clone(&self) -> ConnectionItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectionItem
impl Debug for ConnectionItem
Sourceimpl<'de> Deserialize<'de> for ConnectionItem
impl<'de> Deserialize<'de> for ConnectionItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConnectionItem
impl JsonSchema for ConnectionItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConnectionItem
impl RefUnwindSafe for ConnectionItem
impl Send for ConnectionItem
impl Sync for ConnectionItem
impl Unpin for ConnectionItem
impl UnsafeUnpin for ConnectionItem
impl UnwindSafe for ConnectionItem