pub struct ConnectionPrompt {
pub question: String,
pub answer: String,
pub content_id: Option<String>,
}Fields
question: Stringanswer: Stringcontent_id: Option<String>Trait Implementations
Sourceimpl Clone for ConnectionPrompt
impl Clone for ConnectionPrompt
Sourcefn clone(&self) -> ConnectionPrompt
fn clone(&self) -> ConnectionPrompt
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectionPrompt
impl Debug for ConnectionPrompt
Sourceimpl<'de> Deserialize<'de> for ConnectionPrompt
impl<'de> Deserialize<'de> for ConnectionPrompt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConnectionPrompt
impl JsonSchema for ConnectionPrompt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConnectionPrompt
impl RefUnwindSafe for ConnectionPrompt
impl Send for ConnectionPrompt
impl Sync for ConnectionPrompt
impl Unpin for ConnectionPrompt
impl UnsafeUnpin for ConnectionPrompt
impl UnwindSafe for ConnectionPrompt