pub struct ConnectionVideo {
pub url: String,
pub thumbnail: String,
pub bounding_box: Option<BoundingBox>,
pub cdn_id: Option<String>,
pub content_id: Option<String>,
}Fields
url: Stringthumbnail: Stringbounding_box: Option<BoundingBox>cdn_id: Option<String>content_id: Option<String>Trait Implementations
Sourceimpl Clone for ConnectionVideo
impl Clone for ConnectionVideo
Sourcefn clone(&self) -> ConnectionVideo
fn clone(&self) -> ConnectionVideo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectionVideo
impl Debug for ConnectionVideo
Sourceimpl<'de> Deserialize<'de> for ConnectionVideo
impl<'de> Deserialize<'de> for ConnectionVideo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConnectionVideo
impl JsonSchema for ConnectionVideo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConnectionVideo
impl RefUnwindSafe for ConnectionVideo
impl Send for ConnectionVideo
impl Sync for ConnectionVideo
impl Unpin for ConnectionVideo
impl UnsafeUnpin for ConnectionVideo
impl UnwindSafe for ConnectionVideo