pub struct ConnectionsResponse {
pub connections: Vec<ConnectionItem>,
pub your_turn_match_limit: i32,
}Fields
connections: Vec<ConnectionItem>your_turn_match_limit: i32Trait Implementations
Sourceimpl Clone for ConnectionsResponse
impl Clone for ConnectionsResponse
Sourcefn clone(&self) -> ConnectionsResponse
fn clone(&self) -> ConnectionsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectionsResponse
impl Debug for ConnectionsResponse
Sourceimpl<'de> Deserialize<'de> for ConnectionsResponse
impl<'de> Deserialize<'de> for ConnectionsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConnectionsResponse
impl JsonSchema for ConnectionsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConnectionsResponse
impl RefUnwindSafe for ConnectionsResponse
impl Send for ConnectionsResponse
impl Sync for ConnectionsResponse
impl Unpin for ConnectionsResponse
impl UnsafeUnpin for ConnectionsResponse
impl UnwindSafe for ConnectionsResponse