pub struct ContentData {
pub photos: Vec<PhotoAsset>,
pub answers: Vec<ProfileAnswer>,
pub prompt_poll: Option<PromptPoll>,
pub video_prompt: Option<VideoPrompt>,
}Fields
photos: Vec<PhotoAsset>answers: Vec<ProfileAnswer>prompt_poll: Option<PromptPoll>video_prompt: Option<VideoPrompt>Trait Implementations
Sourceimpl Clone for ContentData
impl Clone for ContentData
Sourcefn clone(&self) -> ContentData
fn clone(&self) -> ContentData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentData
impl Debug for ContentData
Sourceimpl<'de> Deserialize<'de> for ContentData
impl<'de> Deserialize<'de> for ContentData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContentData
impl JsonSchema for ContentData
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContentData
impl RefUnwindSafe for ContentData
impl Send for ContentData
impl Sync for ContentData
impl Unpin for ContentData
impl UnsafeUnpin for ContentData
impl UnwindSafe for ContentData