pub struct Coordinate {
pub x: f64,
pub y: f64,
}Fields
x: f64y: f64Trait Implementations
Sourceimpl Clone for Coordinate
impl Clone for Coordinate
Sourcefn clone(&self) -> Coordinate
fn clone(&self) -> Coordinate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Coordinate
impl Debug for Coordinate
Sourceimpl Default for Coordinate
impl Default for Coordinate
Sourcefn default() -> Coordinate
fn default() -> Coordinate
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for Coordinate
impl<'de> Deserialize<'de> for Coordinate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Coordinate
impl JsonSchema for Coordinate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Coordinate
impl RefUnwindSafe for Coordinate
impl Send for Coordinate
impl Sync for Coordinate
impl Unpin for Coordinate
impl UnsafeUnpin for Coordinate
impl UnwindSafe for Coordinate