pub struct CreatePromptPollRequest {
pub options: Vec<String>,
pub question_id: String,
}Fields
options: Vec<String>question_id: StringTrait Implementations
Sourceimpl Clone for CreatePromptPollRequest
impl Clone for CreatePromptPollRequest
Sourcefn clone(&self) -> CreatePromptPollRequest
fn clone(&self) -> CreatePromptPollRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreatePromptPollRequest
impl Debug for CreatePromptPollRequest
Sourceimpl<'de> Deserialize<'de> for CreatePromptPollRequest
impl<'de> Deserialize<'de> for CreatePromptPollRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreatePromptPollRequest
impl JsonSchema for CreatePromptPollRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreatePromptPollRequest
impl RefUnwindSafe for CreatePromptPollRequest
impl Send for CreatePromptPollRequest
impl Sync for CreatePromptPollRequest
impl Unpin for CreatePromptPollRequest
impl UnsafeUnpin for CreatePromptPollRequest
impl UnwindSafe for CreatePromptPollRequest