pub struct CreatePromptPollResponse {
pub content_id: String,
}Fields
content_id: StringTrait Implementations
Sourceimpl Clone for CreatePromptPollResponse
impl Clone for CreatePromptPollResponse
Sourcefn clone(&self) -> CreatePromptPollResponse
fn clone(&self) -> CreatePromptPollResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreatePromptPollResponse
impl Debug for CreatePromptPollResponse
Sourceimpl<'de> Deserialize<'de> for CreatePromptPollResponse
impl<'de> Deserialize<'de> for CreatePromptPollResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreatePromptPollResponse
impl JsonSchema for CreatePromptPollResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreatePromptPollResponse
impl RefUnwindSafe for CreatePromptPollResponse
impl Send for CreatePromptPollResponse
impl Sync for CreatePromptPollResponse
impl Unpin for CreatePromptPollResponse
impl UnsafeUnpin for CreatePromptPollResponse
impl UnwindSafe for CreatePromptPollResponse