pub struct CreateRate {
pub rating_id: String,
pub hcm_run_id: Option<String>,
pub session_id: String,
pub content: Option<CreateRateContent>,
pub created: String,
pub rating_token: String,
pub initiated_with: Option<String>,
pub rating: String,
pub has_pairing: bool,
pub origin: Option<String>,
pub subject_id: String,
}Fields
rating_id: Stringhcm_run_id: Option<String>session_id: Stringcontent: Option<CreateRateContent>created: Stringrating_token: Stringinitiated_with: Option<String>rating: Stringhas_pairing: boolorigin: Option<String>subject_id: StringTrait Implementations
Sourceimpl Clone for CreateRate
impl Clone for CreateRate
Sourcefn clone(&self) -> CreateRate
fn clone(&self) -> CreateRate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateRate
impl Debug for CreateRate
Sourceimpl<'de> Deserialize<'de> for CreateRate
impl<'de> Deserialize<'de> for CreateRate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateRate
impl JsonSchema for CreateRate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateRate
impl RefUnwindSafe for CreateRate
impl Send for CreateRate
impl Sync for CreateRate
impl Unpin for CreateRate
impl UnsafeUnpin for CreateRate
impl UnwindSafe for CreateRate