pub struct CreateRateContent {
pub comment: Option<String>,
pub photo: Option<PhotoAsset>,
pub prompt: Option<CreateRateContentPrompt>,
}Fields
comment: Option<String>photo: Option<PhotoAsset>prompt: Option<CreateRateContentPrompt>Trait Implementations
Sourceimpl Clone for CreateRateContent
impl Clone for CreateRateContent
Sourcefn clone(&self) -> CreateRateContent
fn clone(&self) -> CreateRateContent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateRateContent
impl Debug for CreateRateContent
Sourceimpl<'de> Deserialize<'de> for CreateRateContent
impl<'de> Deserialize<'de> for CreateRateContent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateRateContent
impl JsonSchema for CreateRateContent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateRateContent
impl RefUnwindSafe for CreateRateContent
impl Send for CreateRateContent
impl Sync for CreateRateContent
impl Unpin for CreateRateContent
impl UnsafeUnpin for CreateRateContent
impl UnwindSafe for CreateRateContent