pub struct CreateRateContentPrompt {
pub answer: String,
pub content_id: Option<String>,
pub question: String,
}Fields
answer: Stringcontent_id: Option<String>question: StringTrait Implementations
Sourceimpl Clone for CreateRateContentPrompt
impl Clone for CreateRateContentPrompt
Sourcefn clone(&self) -> CreateRateContentPrompt
fn clone(&self) -> CreateRateContentPrompt
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateRateContentPrompt
impl Debug for CreateRateContentPrompt
Sourceimpl<'de> Deserialize<'de> for CreateRateContentPrompt
impl<'de> Deserialize<'de> for CreateRateContentPrompt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateRateContentPrompt
impl JsonSchema for CreateRateContentPrompt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateRateContentPrompt
impl RefUnwindSafe for CreateRateContentPrompt
impl Send for CreateRateContentPrompt
impl Sync for CreateRateContentPrompt
impl Unpin for CreateRateContentPrompt
impl UnsafeUnpin for CreateRateContentPrompt
impl UnwindSafe for CreateRateContentPrompt