pub struct CreateVideoPromptRequest {
pub question_id: String,
pub thumbnail_url: String,
pub cdn_id: String,
pub bounding_box: BoundingBox,
pub video_url: String,
pub source: String,
pub length_seconds: i32,
}Fields
question_id: Stringthumbnail_url: Stringcdn_id: Stringbounding_box: BoundingBoxvideo_url: Stringsource: Stringlength_seconds: i32Trait Implementations
Sourceimpl Clone for CreateVideoPromptRequest
impl Clone for CreateVideoPromptRequest
Sourcefn clone(&self) -> CreateVideoPromptRequest
fn clone(&self) -> CreateVideoPromptRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateVideoPromptRequest
impl Debug for CreateVideoPromptRequest
Sourceimpl<'de> Deserialize<'de> for CreateVideoPromptRequest
impl<'de> Deserialize<'de> for CreateVideoPromptRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateVideoPromptRequest
impl JsonSchema for CreateVideoPromptRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateVideoPromptRequest
impl RefUnwindSafe for CreateVideoPromptRequest
impl Send for CreateVideoPromptRequest
impl Sync for CreateVideoPromptRequest
impl Unpin for CreateVideoPromptRequest
impl UnsafeUnpin for CreateVideoPromptRequest
impl UnwindSafe for CreateVideoPromptRequest