pub struct CreateVideoPromptResponse {
pub content_id: String,
}Fields
content_id: StringTrait Implementations
Sourceimpl Clone for CreateVideoPromptResponse
impl Clone for CreateVideoPromptResponse
Sourcefn clone(&self) -> CreateVideoPromptResponse
fn clone(&self) -> CreateVideoPromptResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateVideoPromptResponse
impl Debug for CreateVideoPromptResponse
Sourceimpl<'de> Deserialize<'de> for CreateVideoPromptResponse
impl<'de> Deserialize<'de> for CreateVideoPromptResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateVideoPromptResponse
impl JsonSchema for CreateVideoPromptResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateVideoPromptResponse
impl RefUnwindSafe for CreateVideoPromptResponse
impl Send for CreateVideoPromptResponse
impl Sync for CreateVideoPromptResponse
impl Unpin for CreateVideoPromptResponse
impl UnsafeUnpin for CreateVideoPromptResponse
impl UnwindSafe for CreateVideoPromptResponse