pub struct DatingIntention {
pub value: DatingIntentionProfile,
pub visible: bool,
}Fields
value: DatingIntentionProfilevisible: boolTrait Implementations
Sourceimpl Clone for DatingIntention
impl Clone for DatingIntention
Sourcefn clone(&self) -> DatingIntention
fn clone(&self) -> DatingIntention
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatingIntention
impl Debug for DatingIntention
Sourceimpl<'de> Deserialize<'de> for DatingIntention
impl<'de> Deserialize<'de> for DatingIntention
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DatingIntention
impl JsonSchema for DatingIntention
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DatingIntention
impl RefUnwindSafe for DatingIntention
impl Send for DatingIntention
impl Sync for DatingIntention
impl Unpin for DatingIntention
impl UnsafeUnpin for DatingIntention
impl UnwindSafe for DatingIntention