pub struct Dealbreakers {Show 15 fields
pub marijuana: bool,
pub smoking: bool,
pub max_distance: bool,
pub drinking: bool,
pub education_attained: bool,
pub gendered_height: GenderedDealbreaker,
pub politics: bool,
pub relationship_types: bool,
pub drugs: bool,
pub dating_intentions: bool,
pub family_plans: bool,
pub gendered_age: GenderedDealbreaker,
pub religions: bool,
pub ethnicities: bool,
pub children: bool,
}Fields
marijuana: boolsmoking: boolmax_distance: booldrinking: booleducation_attained: boolgendered_height: GenderedDealbreakerpolitics: boolrelationship_types: booldrugs: booldating_intentions: boolfamily_plans: boolgendered_age: GenderedDealbreakerreligions: boolethnicities: boolchildren: boolTrait Implementations
Sourceimpl Clone for Dealbreakers
impl Clone for Dealbreakers
Sourcefn clone(&self) -> Dealbreakers
fn clone(&self) -> Dealbreakers
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Dealbreakers
impl Debug for Dealbreakers
Sourceimpl<'de> Deserialize<'de> for Dealbreakers
impl<'de> Deserialize<'de> for Dealbreakers
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Dealbreakers
impl JsonSchema for Dealbreakers
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Dealbreakers
impl RefUnwindSafe for Dealbreakers
impl Send for Dealbreakers
impl Sync for Dealbreakers
impl Unpin for Dealbreakers
impl UnsafeUnpin for Dealbreakers
impl UnwindSafe for Dealbreakers