pub struct DrinkingStatus {
pub value: DrinkingStatusProfile,
pub visible: bool,
}Fields
value: DrinkingStatusProfilevisible: boolTrait Implementations
Sourceimpl Clone for DrinkingStatus
impl Clone for DrinkingStatus
Sourcefn clone(&self) -> DrinkingStatus
fn clone(&self) -> DrinkingStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DrinkingStatus
impl Debug for DrinkingStatus
Sourceimpl<'de> Deserialize<'de> for DrinkingStatus
impl<'de> Deserialize<'de> for DrinkingStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DrinkingStatus
impl JsonSchema for DrinkingStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DrinkingStatus
impl RefUnwindSafe for DrinkingStatus
impl Send for DrinkingStatus
impl Sync for DrinkingStatus
impl Unpin for DrinkingStatus
impl UnsafeUnpin for DrinkingStatus
impl UnwindSafe for DrinkingStatus