pub struct DrugStatus {
pub value: DrugStatusProfile,
pub visible: bool,
}Fields
value: DrugStatusProfilevisible: boolTrait Implementations
Sourceimpl Clone for DrugStatus
impl Clone for DrugStatus
Sourcefn clone(&self) -> DrugStatus
fn clone(&self) -> DrugStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DrugStatus
impl Debug for DrugStatus
Sourceimpl<'de> Deserialize<'de> for DrugStatus
impl<'de> Deserialize<'de> for DrugStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DrugStatus
impl JsonSchema for DrugStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DrugStatus
impl RefUnwindSafe for DrugStatus
impl Send for DrugStatus
impl Sync for DrugStatus
impl Unpin for DrugStatus
impl UnsafeUnpin for DrugStatus
impl UnwindSafe for DrugStatus