pub struct Educations {
pub value: Vec<String>,
pub visible: bool,
}Fields
value: Vec<String>visible: boolTrait Implementations
Sourceimpl Clone for Educations
impl Clone for Educations
Sourcefn clone(&self) -> Educations
fn clone(&self) -> Educations
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Educations
impl Debug for Educations
Sourceimpl<'de> Deserialize<'de> for Educations
impl<'de> Deserialize<'de> for Educations
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Educations
impl JsonSchema for Educations
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Educations
impl RefUnwindSafe for Educations
impl Send for Educations
impl Sync for Educations
impl Unpin for Educations
impl UnsafeUnpin for Educations
impl UnwindSafe for Educations