pub struct Ethnicities {
pub value: Vec<EthnicityProfile>,
pub visible: bool,
}Fields
value: Vec<EthnicityProfile>visible: boolTrait Implementations
Sourceimpl Clone for Ethnicities
impl Clone for Ethnicities
Sourcefn clone(&self) -> Ethnicities
fn clone(&self) -> Ethnicities
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Ethnicities
impl Debug for Ethnicities
Sourceimpl<'de> Deserialize<'de> for Ethnicities
impl<'de> Deserialize<'de> for Ethnicities
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Ethnicities
impl JsonSchema for Ethnicities
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Ethnicities
impl RefUnwindSafe for Ethnicities
impl Send for Ethnicities
impl Sync for Ethnicities
impl Unpin for Ethnicities
impl UnsafeUnpin for Ethnicities
impl UnwindSafe for Ethnicities