pub struct ExportChatInput {
pub channel_url: String,
pub output_dir: String,
pub include_media: bool,
pub initiation_summary_lines: Option<Vec<String>>,
}Fields
channel_url: Stringoutput_dir: Stringinclude_media: boolinitiation_summary_lines: Option<Vec<String>>Trait Implementations
Sourceimpl Clone for ExportChatInput
impl Clone for ExportChatInput
Sourcefn clone(&self) -> ExportChatInput
fn clone(&self) -> ExportChatInput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExportChatInput
impl Debug for ExportChatInput
Sourceimpl<'de> Deserialize<'de> for ExportChatInput
impl<'de> Deserialize<'de> for ExportChatInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExportChatInput
impl JsonSchema for ExportChatInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExportChatInput
impl RefUnwindSafe for ExportChatInput
impl Send for ExportChatInput
impl Sync for ExportChatInput
impl Unpin for ExportChatInput
impl UnsafeUnpin for ExportChatInput
impl UnwindSafe for ExportChatInput