pub struct ExportChatResult {
pub folder_path: String,
pub transcript_path: String,
pub profile_path: Option<String>,
pub message_count: i32,
pub media_files: Vec<ExportedMediaFile>,
}Fields
folder_path: Stringtranscript_path: Stringprofile_path: Option<String>message_count: i32media_files: Vec<ExportedMediaFile>Trait Implementations
Sourceimpl Clone for ExportChatResult
impl Clone for ExportChatResult
Sourcefn clone(&self) -> ExportChatResult
fn clone(&self) -> ExportChatResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExportChatResult
impl Debug for ExportChatResult
Sourceimpl<'de> Deserialize<'de> for ExportChatResult
impl<'de> Deserialize<'de> for ExportChatResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExportChatResult
impl JsonSchema for ExportChatResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExportChatResult
impl RefUnwindSafe for ExportChatResult
impl Send for ExportChatResult
impl Sync for ExportChatResult
impl Unpin for ExportChatResult
impl UnsafeUnpin for ExportChatResult
impl UnwindSafe for ExportChatResult