pub struct ExportStatus {
pub status: String,
pub created: Option<String>,
pub url: Option<String>,
}Fields
status: Stringcreated: Option<String>url: Option<String>Trait Implementations
Sourceimpl Clone for ExportStatus
impl Clone for ExportStatus
Sourcefn clone(&self) -> ExportStatus
fn clone(&self) -> ExportStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExportStatus
impl Debug for ExportStatus
Sourceimpl<'de> Deserialize<'de> for ExportStatus
impl<'de> Deserialize<'de> for ExportStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExportStatus
impl JsonSchema for ExportStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExportStatus
impl RefUnwindSafe for ExportStatus
impl Send for ExportStatus
impl Sync for ExportStatus
impl Unpin for ExportStatus
impl UnsafeUnpin for ExportStatus
impl UnwindSafe for ExportStatus