pub struct ExportedMediaFile {
pub message_id: String,
pub file_name: String,
pub file_path: String,
}Fields
message_id: Stringfile_name: Stringfile_path: StringTrait Implementations
Sourceimpl Clone for ExportedMediaFile
impl Clone for ExportedMediaFile
Sourcefn clone(&self) -> ExportedMediaFile
fn clone(&self) -> ExportedMediaFile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExportedMediaFile
impl Debug for ExportedMediaFile
Sourceimpl<'de> Deserialize<'de> for ExportedMediaFile
impl<'de> Deserialize<'de> for ExportedMediaFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExportedMediaFile
impl JsonSchema for ExportedMediaFile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExportedMediaFile
impl RefUnwindSafe for ExportedMediaFile
impl Send for ExportedMediaFile
impl Sync for ExportedMediaFile
impl Unpin for ExportedMediaFile
impl UnsafeUnpin for ExportedMediaFile
impl UnwindSafe for ExportedMediaFile