pub struct FamilyPlans {
pub value: i32,
pub visible: bool,
}Fields
value: i32visible: boolTrait Implementations
Sourceimpl Clone for FamilyPlans
impl Clone for FamilyPlans
Sourcefn clone(&self) -> FamilyPlans
fn clone(&self) -> FamilyPlans
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FamilyPlans
impl Debug for FamilyPlans
Sourceimpl<'de> Deserialize<'de> for FamilyPlans
impl<'de> Deserialize<'de> for FamilyPlans
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FamilyPlans
impl JsonSchema for FamilyPlans
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FamilyPlans
impl RefUnwindSafe for FamilyPlans
impl Send for FamilyPlans
impl Sync for FamilyPlans
impl Unpin for FamilyPlans
impl UnsafeUnpin for FamilyPlans
impl UnwindSafe for FamilyPlans