pub struct Feedback {
pub evaluation: String,
pub detail: String,
pub feedback_token: String,
}Fields
evaluation: Stringdetail: Stringfeedback_token: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Feedback
impl<'de> Deserialize<'de> for Feedback
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Feedback
impl JsonSchema for Feedback
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Feedback
impl RefUnwindSafe for Feedback
impl Send for Feedback
impl Sync for Feedback
impl Unpin for Feedback
impl UnsafeUnpin for Feedback
impl UnwindSafe for Feedback