pub struct HingeAuthToken {
pub identity_id: String,
pub token: String,
pub expires: DateTime<Utc>,
}Fields
identity_id: Stringtoken: Stringexpires: DateTime<Utc>Trait Implementations
Sourceimpl Clone for HingeAuthToken
impl Clone for HingeAuthToken
Sourcefn clone(&self) -> HingeAuthToken
fn clone(&self) -> HingeAuthToken
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HingeAuthToken
impl Debug for HingeAuthToken
Sourceimpl<'de> Deserialize<'de> for HingeAuthToken
impl<'de> Deserialize<'de> for HingeAuthToken
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HingeAuthToken
impl JsonSchema for HingeAuthToken
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HingeAuthToken
impl RefUnwindSafe for HingeAuthToken
impl Send for HingeAuthToken
impl Sync for HingeAuthToken
impl Unpin for HingeAuthToken
impl UnsafeUnpin for HingeAuthToken
impl UnwindSafe for HingeAuthToken