pub struct LanguagesSpoken {
pub value: Vec<i32>,
pub visible: bool,
}Fields
value: Vec<i32>visible: boolTrait Implementations
Sourceimpl Clone for LanguagesSpoken
impl Clone for LanguagesSpoken
Sourcefn clone(&self) -> LanguagesSpoken
fn clone(&self) -> LanguagesSpoken
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LanguagesSpoken
impl Debug for LanguagesSpoken
Sourceimpl<'de> Deserialize<'de> for LanguagesSpoken
impl<'de> Deserialize<'de> for LanguagesSpoken
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LanguagesSpoken
impl JsonSchema for LanguagesSpoken
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LanguagesSpoken
impl RefUnwindSafe for LanguagesSpoken
impl Send for LanguagesSpoken
impl Sync for LanguagesSpoken
impl Unpin for LanguagesSpoken
impl UnsafeUnpin for LanguagesSpoken
impl UnwindSafe for LanguagesSpoken