pub struct LikeItemV2 {
pub player_id: String,
pub subject_id: String,
pub created: String,
pub source: String,
pub initiated_with: String,
pub rating: LikeRating,
}Fields
player_id: Stringsubject_id: Stringcreated: Stringsource: Stringinitiated_with: Stringrating: LikeRatingTrait Implementations
Sourceimpl Clone for LikeItemV2
impl Clone for LikeItemV2
Sourcefn clone(&self) -> LikeItemV2
fn clone(&self) -> LikeItemV2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LikeItemV2
impl Debug for LikeItemV2
Sourceimpl<'de> Deserialize<'de> for LikeItemV2
impl<'de> Deserialize<'de> for LikeItemV2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LikeItemV2
impl JsonSchema for LikeItemV2
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LikeItemV2
impl RefUnwindSafe for LikeItemV2
impl Send for LikeItemV2
impl Sync for LikeItemV2
impl Unpin for LikeItemV2
impl UnsafeUnpin for LikeItemV2
impl UnwindSafe for LikeItemV2