pub struct LikeLimit {
pub likes: i32,
pub superlikes: Option<i32>,
}Fields
likes: i32superlikes: Option<i32>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for LikeLimit
impl<'de> Deserialize<'de> for LikeLimit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LikeLimit
impl JsonSchema for LikeLimit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LikeLimit
impl RefUnwindSafe for LikeLimit
impl Send for LikeLimit
impl Sync for LikeLimit
impl Unpin for LikeLimit
impl UnsafeUnpin for LikeLimit
impl UnwindSafe for LikeLimit