pub struct LikePromptPoll {
pub content_id: Option<String>,
pub options: Vec<String>,
pub question_id: String,
pub selected_option: Option<String>,
pub selected_option_index: Option<i32>,
}Fields
content_id: Option<String>options: Vec<String>question_id: Stringselected_option: Option<String>selected_option_index: Option<i32>Trait Implementations
Sourceimpl Clone for LikePromptPoll
impl Clone for LikePromptPoll
Sourcefn clone(&self) -> LikePromptPoll
fn clone(&self) -> LikePromptPoll
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LikePromptPoll
impl Debug for LikePromptPoll
Sourceimpl<'de> Deserialize<'de> for LikePromptPoll
impl<'de> Deserialize<'de> for LikePromptPoll
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LikePromptPoll
impl JsonSchema for LikePromptPoll
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LikePromptPoll
impl RefUnwindSafe for LikePromptPoll
impl Send for LikePromptPoll
impl Sync for LikePromptPoll
impl Unpin for LikePromptPoll
impl UnsafeUnpin for LikePromptPoll
impl UnwindSafe for LikePromptPoll