pub struct LikeRating {
pub content: Vec<LikeRatingContentItem>,
}Fields
content: Vec<LikeRatingContentItem>Trait Implementations
Sourceimpl Clone for LikeRating
impl Clone for LikeRating
Sourcefn clone(&self) -> LikeRating
fn clone(&self) -> LikeRating
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LikeRating
impl Debug for LikeRating
Sourceimpl<'de> Deserialize<'de> for LikeRating
impl<'de> Deserialize<'de> for LikeRating
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LikeRating
impl JsonSchema for LikeRating
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LikeRating
impl RefUnwindSafe for LikeRating
impl Send for LikeRating
impl Sync for LikeRating
impl Unpin for LikeRating
impl UnsafeUnpin for LikeRating
impl UnwindSafe for LikeRating