pub struct LikeRatingContentItem {
pub photo: Option<PhotoAsset>,
pub prompt: Option<CreateRateContentPrompt>,
pub comment: Option<String>,
pub prompt_poll: Option<LikePromptPoll>,
}Fields
photo: Option<PhotoAsset>prompt: Option<CreateRateContentPrompt>comment: Option<String>prompt_poll: Option<LikePromptPoll>Trait Implementations
Sourceimpl Clone for LikeRatingContentItem
impl Clone for LikeRatingContentItem
Sourcefn clone(&self) -> LikeRatingContentItem
fn clone(&self) -> LikeRatingContentItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LikeRatingContentItem
impl Debug for LikeRatingContentItem
Sourceimpl<'de> Deserialize<'de> for LikeRatingContentItem
impl<'de> Deserialize<'de> for LikeRatingContentItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LikeRatingContentItem
impl JsonSchema for LikeRatingContentItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LikeRatingContentItem
impl RefUnwindSafe for LikeRatingContentItem
impl Send for LikeRatingContentItem
impl Sync for LikeRatingContentItem
impl Unpin for LikeRatingContentItem
impl UnsafeUnpin for LikeRatingContentItem
impl UnwindSafe for LikeRatingContentItem