pub struct LikeResponse {
pub limit: LikeLimit,
}Fields
limit: LikeLimitTrait Implementations
Sourceimpl Clone for LikeResponse
impl Clone for LikeResponse
Sourcefn clone(&self) -> LikeResponse
fn clone(&self) -> LikeResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LikeResponse
impl Debug for LikeResponse
Sourceimpl<'de> Deserialize<'de> for LikeResponse
impl<'de> Deserialize<'de> for LikeResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LikeResponse
impl JsonSchema for LikeResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LikeResponse
impl RefUnwindSafe for LikeResponse
impl Send for LikeResponse
impl Sync for LikeResponse
impl Unpin for LikeResponse
impl UnsafeUnpin for LikeResponse
impl UnwindSafe for LikeResponse