pub struct LikeSortV2 {
pub id: String,
pub title: String,
}Fields
id: Stringtitle: StringTrait Implementations
Sourceimpl Clone for LikeSortV2
impl Clone for LikeSortV2
Sourcefn clone(&self) -> LikeSortV2
fn clone(&self) -> LikeSortV2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LikeSortV2
impl Debug for LikeSortV2
Sourceimpl<'de> Deserialize<'de> for LikeSortV2
impl<'de> Deserialize<'de> for LikeSortV2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LikeSortV2
impl JsonSchema for LikeSortV2
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LikeSortV2
impl RefUnwindSafe for LikeSortV2
impl Send for LikeSortV2
impl Sync for LikeSortV2
impl Unpin for LikeSortV2
impl UnsafeUnpin for LikeSortV2
impl UnwindSafe for LikeSortV2