pub struct LikesV2Response {
pub likes: Vec<LikeItemV2>,
pub hidden_likes: Vec<Value>,
pub sorts: Vec<LikeSortV2>,
pub sorted_likes: Vec<SortedLikesGroupV2>,
}Fields
likes: Vec<LikeItemV2>sorts: Vec<LikeSortV2>sorted_likes: Vec<SortedLikesGroupV2>Trait Implementations
Sourceimpl Clone for LikesV2Response
impl Clone for LikesV2Response
Sourcefn clone(&self) -> LikesV2Response
fn clone(&self) -> LikesV2Response
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LikesV2Response
impl Debug for LikesV2Response
Sourceimpl<'de> Deserialize<'de> for LikesV2Response
impl<'de> Deserialize<'de> for LikesV2Response
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LikesV2Response
impl JsonSchema for LikesV2Response
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LikesV2Response
impl RefUnwindSafe for LikesV2Response
impl Send for LikesV2Response
impl Sync for LikesV2Response
impl Unpin for LikesV2Response
impl UnsafeUnpin for LikesV2Response
impl UnwindSafe for LikesV2Response