pub struct Location {
pub name: String,
pub latitude: Option<f64>,
pub longitude: Option<f64>,
pub metro_area: Option<String>,
pub metro_area_v2: Option<String>,
pub country_short: Option<String>,
pub admin_area1_long: Option<String>,
pub admin_area1_short: Option<String>,
pub admin_area2: Option<String>,
}Fields
name: Stringlatitude: Option<f64>longitude: Option<f64>metro_area: Option<String>metro_area_v2: Option<String>country_short: Option<String>admin_area1_long: Option<String>admin_area1_short: Option<String>admin_area2: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Location
impl<'de> Deserialize<'de> for Location
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Location
impl JsonSchema for Location
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Location
impl RefUnwindSafe for Location
impl Send for Location
impl Sync for Location
impl Unpin for Location
impl UnsafeUnpin for Location
impl UnwindSafe for Location