pub struct MatchNoteResponse {
pub note: String,
}Fields
note: StringTrait Implementations
Sourceimpl Clone for MatchNoteResponse
impl Clone for MatchNoteResponse
Sourcefn clone(&self) -> MatchNoteResponse
fn clone(&self) -> MatchNoteResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatchNoteResponse
impl Debug for MatchNoteResponse
Sourceimpl<'de> Deserialize<'de> for MatchNoteResponse
impl<'de> Deserialize<'de> for MatchNoteResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MatchNoteResponse
impl JsonSchema for MatchNoteResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MatchNoteResponse
impl RefUnwindSafe for MatchNoteResponse
impl Send for MatchNoteResponse
impl Sync for MatchNoteResponse
impl Unpin for MatchNoteResponse
impl UnsafeUnpin for MatchNoteResponse
impl UnwindSafe for MatchNoteResponse