pub struct PhotoAsset {Show 15 fields
pub id: Option<String>,
pub url: String,
pub cdn_id: Option<String>,
pub content_id: Option<String>,
pub prompt_id: Option<String>,
pub caption: Option<String>,
pub width: Option<i32>,
pub height: Option<i32>,
pub video_url: Option<String>,
pub selfie_verified: Option<bool>,
pub bounding_box: Option<BoundingBox>,
pub location: Option<String>,
pub source: Option<String>,
pub source_id: Option<String>,
pub p_hash: Option<String>,
}Fields
id: Option<String>url: Stringcdn_id: Option<String>content_id: Option<String>prompt_id: Option<String>caption: Option<String>width: Option<i32>height: Option<i32>video_url: Option<String>selfie_verified: Option<bool>bounding_box: Option<BoundingBox>location: Option<String>source: Option<String>source_id: Option<String>p_hash: Option<String>Trait Implementations
Sourceimpl Clone for PhotoAsset
impl Clone for PhotoAsset
Sourcefn clone(&self) -> PhotoAsset
fn clone(&self) -> PhotoAsset
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PhotoAsset
impl Debug for PhotoAsset
Sourceimpl<'de> Deserialize<'de> for PhotoAsset
impl<'de> Deserialize<'de> for PhotoAsset
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PhotoAsset
impl JsonSchema for PhotoAsset
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PhotoAsset
impl RefUnwindSafe for PhotoAsset
impl Send for PhotoAsset
impl Sync for PhotoAsset
impl Unpin for PhotoAsset
impl UnsafeUnpin for PhotoAsset
impl UnwindSafe for PhotoAsset