pub struct PhotoAssetInput {
pub url: String,
pub content_id: Option<String>,
pub cdn_id: Option<String>,
pub bounding_box: Option<BoundingBox>,
pub selfie_verified: Option<bool>,
}Fields
url: Stringcontent_id: Option<String>cdn_id: Option<String>bounding_box: Option<BoundingBox>selfie_verified: Option<bool>Trait Implementations
Sourceimpl Clone for PhotoAssetInput
impl Clone for PhotoAssetInput
Sourcefn clone(&self) -> PhotoAssetInput
fn clone(&self) -> PhotoAssetInput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PhotoAssetInput
impl Debug for PhotoAssetInput
Sourceimpl<'de> Deserialize<'de> for PhotoAssetInput
impl<'de> Deserialize<'de> for PhotoAssetInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PhotoAssetInput
impl JsonSchema for PhotoAssetInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PhotoAssetInput
impl RefUnwindSafe for PhotoAssetInput
impl Send for PhotoAssetInput
impl Sync for PhotoAssetInput
impl Unpin for PhotoAssetInput
impl UnsafeUnpin for PhotoAssetInput
impl UnwindSafe for PhotoAssetInput