pub struct Politics {
pub value: PoliticsProfile,
pub visible: bool,
}Fields
value: PoliticsProfilevisible: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Politics
impl<'de> Deserialize<'de> for Politics
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Politics
impl JsonSchema for Politics
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Politics
impl RefUnwindSafe for Politics
impl Send for Politics
impl Sync for Politics
impl Unpin for Politics
impl UnsafeUnpin for Politics
impl UnwindSafe for Politics