pub struct Preferences {Show 17 fields
pub gendered_age_ranges: GenderedRange,
pub dealbreakers: Dealbreakers,
pub religions: Vec<ReligionPreference>,
pub drinking: Vec<DrinkingStatusPreference>,
pub gendered_height_ranges: GenderedRange,
pub marijuana: Vec<MarijuanaStatusPreference>,
pub relationship_types: Vec<RelationshipTypePreference>,
pub drugs: Vec<DrugStatusPreference>,
pub max_distance: i32,
pub children: Vec<ChildrenStatusPreference>,
pub ethnicities: Vec<EthnicityPreference>,
pub smoking: Vec<SmokingStatusPreference>,
pub education_attained: Vec<EducationAttainedPreference>,
pub family_plans: Vec<i32>,
pub dating_intentions: Vec<DatingIntentionPreference>,
pub politics: Vec<PoliticsPreference>,
pub gender_preferences: Vec<GenderPreferences>,
}Fields
gendered_age_ranges: GenderedRangedealbreakers: Dealbreakersreligions: Vec<ReligionPreference>drinking: Vec<DrinkingStatusPreference>gendered_height_ranges: GenderedRangemarijuana: Vec<MarijuanaStatusPreference>relationship_types: Vec<RelationshipTypePreference>drugs: Vec<DrugStatusPreference>max_distance: i32children: Vec<ChildrenStatusPreference>ethnicities: Vec<EthnicityPreference>smoking: Vec<SmokingStatusPreference>education_attained: Vec<EducationAttainedPreference>family_plans: Vec<i32>dating_intentions: Vec<DatingIntentionPreference>politics: Vec<PoliticsPreference>gender_preferences: Vec<GenderPreferences>Trait Implementations
Sourceimpl Clone for Preferences
impl Clone for Preferences
Sourcefn clone(&self) -> Preferences
fn clone(&self) -> Preferences
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Preferences
impl Debug for Preferences
Sourceimpl<'de> Deserialize<'de> for Preferences
impl<'de> Deserialize<'de> for Preferences
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Preferences
impl JsonSchema for Preferences
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Preferences
impl RefUnwindSafe for Preferences
impl Send for Preferences
impl Sync for Preferences
impl Unpin for Preferences
impl UnsafeUnpin for Preferences
impl UnwindSafe for Preferences