pub struct Profile {Show 44 fields
pub age: Option<i32>,
pub birthday: Option<String>,
pub covid_vax: Option<i32>,
pub children: Option<ChildrenStatus>,
pub dating_intention: Option<DatingIntention>,
pub dating_intention_text: Option<String>,
pub drinking: Option<DrinkingStatus>,
pub drugs: Option<DrugStatus>,
pub education_attained: Option<EducationAttainedProfile>,
pub educations: Option<Educations>,
pub email: Option<String>,
pub email_verified: Option<bool>,
pub ethnicities: Option<Ethnicities>,
pub ethnicities_text: Option<String>,
pub family_plans: Option<FamilyPlans>,
pub first_name: String,
pub first_completed_date: Option<String>,
pub gender_id: Option<GenderEnum>,
pub gender_identity_id: Option<GenderIdentityId>,
pub gender_identity: Option<String>,
pub height: Option<i32>,
pub hometown: Option<Hometown>,
pub job_title: Option<JobTitle>,
pub languages_spoken: Option<LanguagesSpoken>,
pub last_name: Option<String>,
pub location: Location,
pub marijuana: Option<MarijuanaStatus>,
pub pets: Option<Value>,
pub phone: Option<String>,
pub politics: Option<Politics>,
pub pronouns: Option<Pronouns>,
pub relationship_type_ids: Option<RelationshipTypeIds>,
pub relationship_types_text: Option<String>,
pub religions: Option<Religion>,
pub selfie_verified: Option<bool>,
pub sexual_orientations: Option<SexualOrientations>,
pub smoking: Option<SmokingStatus>,
pub works: Option<Works>,
pub zodiac: Option<Zodiac>,
pub last_active_status_id: Option<i32>,
pub did_just_join: Option<bool>,
pub name: Option<ProfileName>,
pub photos: Vec<PhotoAsset>,
pub answers: Vec<ProfileAnswer>,
}Fields
age: Option<i32>birthday: Option<String>covid_vax: Option<i32>children: Option<ChildrenStatus>dating_intention: Option<DatingIntention>dating_intention_text: Option<String>drinking: Option<DrinkingStatus>drugs: Option<DrugStatus>education_attained: Option<EducationAttainedProfile>educations: Option<Educations>email: Option<String>email_verified: Option<bool>ethnicities: Option<Ethnicities>ethnicities_text: Option<String>family_plans: Option<FamilyPlans>first_name: Stringfirst_completed_date: Option<String>gender_id: Option<GenderEnum>gender_identity_id: Option<GenderIdentityId>gender_identity: Option<String>height: Option<i32>hometown: Option<Hometown>job_title: Option<JobTitle>languages_spoken: Option<LanguagesSpoken>last_name: Option<String>location: Locationmarijuana: Option<MarijuanaStatus>pets: Option<Value>phone: Option<String>politics: Option<Politics>pronouns: Option<Pronouns>relationship_type_ids: Option<RelationshipTypeIds>relationship_types_text: Option<String>religions: Option<Religion>selfie_verified: Option<bool>sexual_orientations: Option<SexualOrientations>smoking: Option<SmokingStatus>works: Option<Works>zodiac: Option<Zodiac>last_active_status_id: Option<i32>did_just_join: Option<bool>name: Option<ProfileName>photos: Vec<PhotoAsset>answers: Vec<ProfileAnswer>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Profile
impl<'de> Deserialize<'de> for Profile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Profile
impl JsonSchema for Profile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Profile
impl RefUnwindSafe for Profile
impl Send for Profile
impl Sync for Profile
impl Unpin for Profile
impl UnsafeUnpin for Profile
impl UnwindSafe for Profile