pub struct ProfileAnswer {Show 13 fields
pub prompt_id: Option<String>,
pub content: Option<String>,
pub content_id: Option<String>,
pub position: Option<i32>,
pub question_id: Option<String>,
pub response: Option<String>,
pub answer_type: Option<String>,
pub feedback: Option<Feedback>,
pub transcription_metadata: Option<Value>,
pub url: Option<String>,
pub cdn_id: Option<String>,
pub waveform: Option<String>,
pub transcription: Option<String>,
}Fields
prompt_id: Option<String>content: Option<String>content_id: Option<String>position: Option<i32>question_id: Option<String>response: Option<String>answer_type: Option<String>feedback: Option<Feedback>transcription_metadata: Option<Value>url: Option<String>cdn_id: Option<String>waveform: Option<String>transcription: Option<String>Trait Implementations
Sourceimpl Clone for ProfileAnswer
impl Clone for ProfileAnswer
Sourcefn clone(&self) -> ProfileAnswer
fn clone(&self) -> ProfileAnswer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileAnswer
impl Debug for ProfileAnswer
Sourceimpl<'de> Deserialize<'de> for ProfileAnswer
impl<'de> Deserialize<'de> for ProfileAnswer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileAnswer
impl JsonSchema for ProfileAnswer
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileAnswer
impl RefUnwindSafe for ProfileAnswer
impl Send for ProfileAnswer
impl Sync for ProfileAnswer
impl Unpin for ProfileAnswer
impl UnsafeUnpin for ProfileAnswer
impl UnwindSafe for ProfileAnswer