pub struct ProfileContent {
pub name: ProfileName,
pub photos: Vec<PhotoAsset>,
pub answers: Vec<ProfileAnswer>,
}Fields
name: ProfileNamephotos: Vec<PhotoAsset>answers: Vec<ProfileAnswer>Trait Implementations
Sourceimpl Clone for ProfileContent
impl Clone for ProfileContent
Sourcefn clone(&self) -> ProfileContent
fn clone(&self) -> ProfileContent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileContent
impl Debug for ProfileContent
Sourceimpl<'de> Deserialize<'de> for ProfileContent
impl<'de> Deserialize<'de> for ProfileContent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileContent
impl JsonSchema for ProfileContent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileContent
impl RefUnwindSafe for ProfileContent
impl Send for ProfileContent
impl Sync for ProfileContent
impl Unpin for ProfileContent
impl UnsafeUnpin for ProfileContent
impl UnwindSafe for ProfileContent