pub struct ProfileContentContent {
pub photos: Vec<PhotoAsset>,
pub answers: Vec<ProfileAnswer>,
pub prompt_poll: Option<PromptPoll>,
pub video_prompt: Option<VideoPrompt>,
}Fields
photos: Vec<PhotoAsset>answers: Vec<ProfileAnswer>prompt_poll: Option<PromptPoll>video_prompt: Option<VideoPrompt>Trait Implementations
Sourceimpl Clone for ProfileContentContent
impl Clone for ProfileContentContent
Sourcefn clone(&self) -> ProfileContentContent
fn clone(&self) -> ProfileContentContent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileContentContent
impl Debug for ProfileContentContent
Sourceimpl<'de> Deserialize<'de> for ProfileContentContent
impl<'de> Deserialize<'de> for ProfileContentContent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileContentContent
impl JsonSchema for ProfileContentContent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileContentContent
impl RefUnwindSafe for ProfileContentContent
impl Send for ProfileContentContent
impl Sync for ProfileContentContent
impl Unpin for ProfileContentContent
impl UnsafeUnpin for ProfileContentContent
impl UnwindSafe for ProfileContentContent