pub struct ProfileContentFull {
pub user_id: String,
pub content: ProfileContentContent,
}Fields
user_id: Stringcontent: ProfileContentContentTrait Implementations
Sourceimpl Clone for ProfileContentFull
impl Clone for ProfileContentFull
Sourcefn clone(&self) -> ProfileContentFull
fn clone(&self) -> ProfileContentFull
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileContentFull
impl Debug for ProfileContentFull
Sourceimpl<'de> Deserialize<'de> for ProfileContentFull
impl<'de> Deserialize<'de> for ProfileContentFull
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileContentFull
impl JsonSchema for ProfileContentFull
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileContentFull
impl RefUnwindSafe for ProfileContentFull
impl Send for ProfileContentFull
impl Sync for ProfileContentFull
impl Unpin for ProfileContentFull
impl UnsafeUnpin for ProfileContentFull
impl UnwindSafe for ProfileContentFull