pub struct ProfileName {
pub first_name: String,
pub last_name: Option<String>,
}Fields
first_name: Stringlast_name: Option<String>Trait Implementations
Sourceimpl Clone for ProfileName
impl Clone for ProfileName
Sourcefn clone(&self) -> ProfileName
fn clone(&self) -> ProfileName
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileName
impl Debug for ProfileName
Sourceimpl<'de> Deserialize<'de> for ProfileName
impl<'de> Deserialize<'de> for ProfileName
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileName
impl JsonSchema for ProfileName
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileName
impl RefUnwindSafe for ProfileName
impl Send for ProfileName
impl Sync for ProfileName
impl Unpin for ProfileName
impl UnsafeUnpin for ProfileName
impl UnwindSafe for ProfileName