pub struct ProfileUpdate {Show 16 fields
pub children: Option<ChildrenStatus>,
pub dating_intention: Option<DatingIntention>,
pub drinking: Option<DrinkingStatus>,
pub drugs: Option<DrugStatus>,
pub marijuana: Option<MarijuanaStatus>,
pub smoking: Option<SmokingStatus>,
pub politics: Option<Politics>,
pub religions: Option<Religion>,
pub ethnicities: Option<Ethnicities>,
pub education_attained: Option<EducationAttainedProfile>,
pub relationship_type_ids: Option<RelationshipTypeIds>,
pub height: Option<i32>,
pub gender_id: Option<GenderEnum>,
pub hometown: Option<Hometown>,
pub languages_spoken: Option<LanguagesSpoken>,
pub zodiac: Option<Zodiac>,
}Fields
children: Option<ChildrenStatus>dating_intention: Option<DatingIntention>drinking: Option<DrinkingStatus>drugs: Option<DrugStatus>marijuana: Option<MarijuanaStatus>smoking: Option<SmokingStatus>politics: Option<Politics>religions: Option<Religion>ethnicities: Option<Ethnicities>education_attained: Option<EducationAttainedProfile>relationship_type_ids: Option<RelationshipTypeIds>height: Option<i32>gender_id: Option<GenderEnum>hometown: Option<Hometown>languages_spoken: Option<LanguagesSpoken>zodiac: Option<Zodiac>Trait Implementations
Sourceimpl Clone for ProfileUpdate
impl Clone for ProfileUpdate
Sourcefn clone(&self) -> ProfileUpdate
fn clone(&self) -> ProfileUpdate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileUpdate
impl Debug for ProfileUpdate
Sourceimpl<'de> Deserialize<'de> for ProfileUpdate
impl<'de> Deserialize<'de> for ProfileUpdate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileUpdate
impl JsonSchema for ProfileUpdate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileUpdate
impl RefUnwindSafe for ProfileUpdate
impl Send for ProfileUpdate
impl Sync for ProfileUpdate
impl Unpin for ProfileUpdate
impl UnsafeUnpin for ProfileUpdate
impl UnwindSafe for ProfileUpdate