pub struct Prompt {
pub id: String,
pub prompt: String,
pub is_selectable: bool,
pub placeholder: String,
pub is_new: bool,
pub categories: Vec<String>,
pub content_types: Vec<ContentType>,
}Fields
id: Stringprompt: Stringis_selectable: boolplaceholder: Stringis_new: boolcategories: Vec<String>content_types: Vec<ContentType>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Prompt
impl<'de> Deserialize<'de> for Prompt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Prompt
impl JsonSchema for Prompt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Prompt
impl RefUnwindSafe for Prompt
impl Send for Prompt
impl Sync for Prompt
impl Unpin for Prompt
impl UnsafeUnpin for Prompt
impl UnwindSafe for Prompt