pub struct PromptCategory {
pub name: String,
pub slug: String,
pub is_visible: bool,
pub is_new: bool,
}Fields
name: Stringslug: Stringis_visible: boolis_new: boolTrait Implementations
Sourceimpl Clone for PromptCategory
impl Clone for PromptCategory
Sourcefn clone(&self) -> PromptCategory
fn clone(&self) -> PromptCategory
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromptCategory
impl Debug for PromptCategory
Sourceimpl<'de> Deserialize<'de> for PromptCategory
impl<'de> Deserialize<'de> for PromptCategory
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PromptCategory
impl JsonSchema for PromptCategory
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PromptCategory
impl RefUnwindSafe for PromptCategory
impl Send for PromptCategory
impl Sync for PromptCategory
impl Unpin for PromptCategory
impl UnsafeUnpin for PromptCategory
impl UnwindSafe for PromptCategory