pub struct PromptPoll {
pub content_id: String,
pub question_id: String,
pub options: Vec<String>,
}Fields
content_id: Stringquestion_id: Stringoptions: Vec<String>Trait Implementations
Sourceimpl Clone for PromptPoll
impl Clone for PromptPoll
Sourcefn clone(&self) -> PromptPoll
fn clone(&self) -> PromptPoll
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromptPoll
impl Debug for PromptPoll
Sourceimpl<'de> Deserialize<'de> for PromptPoll
impl<'de> Deserialize<'de> for PromptPoll
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PromptPoll
impl JsonSchema for PromptPoll
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PromptPoll
impl RefUnwindSafe for PromptPoll
impl Send for PromptPoll
impl Sync for PromptPoll
impl Unpin for PromptPoll
impl UnsafeUnpin for PromptPoll
impl UnwindSafe for PromptPoll