pub struct PromptsResponse {
pub prompts: Vec<Prompt>,
pub categories: Vec<PromptCategory>,
}Fields
prompts: Vec<Prompt>categories: Vec<PromptCategory>Trait Implementations
Sourceimpl Clone for PromptsResponse
impl Clone for PromptsResponse
Sourcefn clone(&self) -> PromptsResponse
fn clone(&self) -> PromptsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromptsResponse
impl Debug for PromptsResponse
Sourceimpl<'de> Deserialize<'de> for PromptsResponse
impl<'de> Deserialize<'de> for PromptsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PromptsResponse
impl JsonSchema for PromptsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PromptsResponse
impl RefUnwindSafe for PromptsResponse
impl Send for PromptsResponse
impl Sync for PromptsResponse
impl Unpin for PromptsResponse
impl UnsafeUnpin for PromptsResponse
impl UnwindSafe for PromptsResponse