pub struct PublicProfile {Show 41 fields
pub age: Option<i32>,
pub birthday: Option<String>,
pub covid_vax: Option<i32>,
pub children: Option<i32>,
pub dating_intention: Option<i32>,
pub dating_intention_text: Option<String>,
pub drinking: Option<i32>,
pub drugs: Option<i32>,
pub education_attained: Option<EducationAttainedProfile>,
pub educations: Option<Vec<String>>,
pub email: Option<String>,
pub email_verified: Option<bool>,
pub ethnicities: Option<Vec<i32>>,
pub ethnicities_text: Option<String>,
pub family_plans: Option<i32>,
pub first_name: String,
pub first_completed_date: Option<String>,
pub gender_id: Option<GenderEnum>,
pub gender_identity_id: Option<i32>,
pub gender_identity: Option<String>,
pub height: Option<i32>,
pub hometown: Option<String>,
pub job_title: Option<String>,
pub languages_spoken: Option<Vec<i32>>,
pub last_name: Option<String>,
pub location: Location,
pub marijuana: Option<i32>,
pub pets: Option<Vec<i32>>,
pub phone: Option<String>,
pub politics: Option<i32>,
pub pronouns: Option<Vec<i32>>,
pub relationship_type_ids: Option<Vec<i32>>,
pub relationship_types_text: Option<String>,
pub religions: Option<Vec<i32>>,
pub selfie_verified: Option<bool>,
pub sexual_orientations: Option<Vec<i32>>,
pub smoking: Option<i32>,
pub works: Option<String>,
pub zodiac: Option<i32>,
pub last_active_status_id: Option<i32>,
pub did_just_join: Option<bool>,
}Fields
age: Option<i32>birthday: Option<String>covid_vax: Option<i32>children: Option<i32>dating_intention: Option<i32>dating_intention_text: Option<String>drinking: Option<i32>drugs: Option<i32>education_attained: Option<EducationAttainedProfile>educations: Option<Vec<String>>email: Option<String>email_verified: Option<bool>ethnicities: Option<Vec<i32>>ethnicities_text: Option<String>family_plans: Option<i32>first_name: Stringfirst_completed_date: Option<String>gender_id: Option<GenderEnum>gender_identity_id: Option<i32>gender_identity: Option<String>height: Option<i32>hometown: Option<String>job_title: Option<String>languages_spoken: Option<Vec<i32>>last_name: Option<String>location: Locationmarijuana: Option<i32>pets: Option<Vec<i32>>phone: Option<String>politics: Option<i32>pronouns: Option<Vec<i32>>relationship_type_ids: Option<Vec<i32>>relationship_types_text: Option<String>religions: Option<Vec<i32>>selfie_verified: Option<bool>sexual_orientations: Option<Vec<i32>>smoking: Option<i32>works: Option<String>zodiac: Option<i32>last_active_status_id: Option<i32>did_just_join: Option<bool>Trait Implementations
Sourceimpl Clone for PublicProfile
impl Clone for PublicProfile
Sourcefn clone(&self) -> PublicProfile
fn clone(&self) -> PublicProfile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublicProfile
impl Debug for PublicProfile
Sourceimpl<'de> Deserialize<'de> for PublicProfile
impl<'de> Deserialize<'de> for PublicProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PublicProfile
impl JsonSchema for PublicProfile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PublicProfile
impl RefUnwindSafe for PublicProfile
impl Send for PublicProfile
impl Sync for PublicProfile
impl Unpin for PublicProfile
impl UnsafeUnpin for PublicProfile
impl UnwindSafe for PublicProfile