pub struct PublicUserProfile {
pub user_id: String,
pub profile: PublicProfile,
}Fields
user_id: Stringprofile: PublicProfileTrait Implementations
Sourceimpl Clone for PublicUserProfile
impl Clone for PublicUserProfile
Sourcefn clone(&self) -> PublicUserProfile
fn clone(&self) -> PublicUserProfile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublicUserProfile
impl Debug for PublicUserProfile
Sourceimpl<'de> Deserialize<'de> for PublicUserProfile
impl<'de> Deserialize<'de> for PublicUserProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PublicUserProfile
impl JsonSchema for PublicUserProfile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PublicUserProfile
impl RefUnwindSafe for PublicUserProfile
impl Send for PublicUserProfile
impl Sync for PublicUserProfile
impl Unpin for PublicUserProfile
impl UnsafeUnpin for PublicUserProfile
impl UnwindSafe for PublicUserProfile