pub struct RangeDetails {
pub max: Option<i32>,
pub min: Option<i32>,
}Fields
max: Option<i32>min: Option<i32>Trait Implementations
Sourceimpl Clone for RangeDetails
impl Clone for RangeDetails
Sourcefn clone(&self) -> RangeDetails
fn clone(&self) -> RangeDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RangeDetails
impl Debug for RangeDetails
Sourceimpl<'de> Deserialize<'de> for RangeDetails
impl<'de> Deserialize<'de> for RangeDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RangeDetails
impl JsonSchema for RangeDetails
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RangeDetails
impl RefUnwindSafe for RangeDetails
impl Send for RangeDetails
impl Sync for RangeDetails
impl Unpin for RangeDetails
impl UnsafeUnpin for RangeDetails
impl UnwindSafe for RangeDetails