pub struct RateContentPayload {
pub comment: Option<String>,
pub photo: Option<Value>,
pub prompt: Option<Value>,
}Fields
comment: Option<String>photo: Option<Value>prompt: Option<Value>Trait Implementations
Sourceimpl Clone for RateContentPayload
impl Clone for RateContentPayload
Sourcefn clone(&self) -> RateContentPayload
fn clone(&self) -> RateContentPayload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateContentPayload
impl Debug for RateContentPayload
Sourceimpl<'de> Deserialize<'de> for RateContentPayload
impl<'de> Deserialize<'de> for RateContentPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RateContentPayload
impl JsonSchema for RateContentPayload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RateContentPayload
impl RefUnwindSafe for RateContentPayload
impl Send for RateContentPayload
impl Sync for RateContentPayload
impl Unpin for RateContentPayload
impl UnsafeUnpin for RateContentPayload
impl UnwindSafe for RateContentPayload