pub struct RateInput {
pub subject_id: String,
pub rating_token: String,
pub origin: Option<String>,
pub use_superlike: Option<bool>,
pub photo: Option<PhotoAssetInput>,
pub answer_text: Option<String>,
pub question_text: Option<String>,
pub content_id: Option<String>,
pub comment: Option<String>,
}Fields
subject_id: Stringrating_token: Stringorigin: Option<String>use_superlike: Option<bool>photo: Option<PhotoAssetInput>answer_text: Option<String>question_text: Option<String>content_id: Option<String>comment: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for RateInput
impl<'de> Deserialize<'de> for RateInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RateInput
impl JsonSchema for RateInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RateInput
impl RefUnwindSafe for RateInput
impl Send for RateInput
impl Sync for RateInput
impl Unpin for RateInput
impl UnsafeUnpin for RateInput
impl UnwindSafe for RateInput