pub struct RatePayload {
pub rating_id: String,
pub rating_token: String,
pub subject_id: String,
pub session_id: String,
pub rating: String,
pub origin: String,
pub has_pairing: bool,
pub created: String,
pub initiated_with: String,
pub content: Option<RateContentPayload>,
}Fields
rating_id: Stringrating_token: Stringsubject_id: Stringsession_id: Stringrating: Stringorigin: Stringhas_pairing: boolcreated: Stringinitiated_with: Stringcontent: Option<RateContentPayload>Trait Implementations
Sourceimpl Clone for RatePayload
impl Clone for RatePayload
Sourcefn clone(&self) -> RatePayload
fn clone(&self) -> RatePayload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RatePayload
impl Debug for RatePayload
Sourceimpl<'de> Deserialize<'de> for RatePayload
impl<'de> Deserialize<'de> for RatePayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RatePayload
impl JsonSchema for RatePayload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RatePayload
impl RefUnwindSafe for RatePayload
impl Send for RatePayload
impl Sync for RatePayload
impl Unpin for RatePayload
impl UnsafeUnpin for RatePayload
impl UnwindSafe for RatePayload