pub struct RateRespondRequest {
pub sort_type: String,
pub subject_id: String,
pub rating_id: Option<String>,
pub origin: String,
pub session_id: Option<String>,
pub initiated_with: Option<String>,
pub rating: String,
pub created: Option<String>,
}Fields
sort_type: Stringsubject_id: Stringrating_id: Option<String>origin: Stringsession_id: Option<String>initiated_with: Option<String>rating: Stringcreated: Option<String>Trait Implementations
Sourceimpl Clone for RateRespondRequest
impl Clone for RateRespondRequest
Sourcefn clone(&self) -> RateRespondRequest
fn clone(&self) -> RateRespondRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateRespondRequest
impl Debug for RateRespondRequest
Sourceimpl<'de> Deserialize<'de> for RateRespondRequest
impl<'de> Deserialize<'de> for RateRespondRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RateRespondRequest
impl JsonSchema for RateRespondRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RateRespondRequest
impl RefUnwindSafe for RateRespondRequest
impl Send for RateRespondRequest
impl Sync for RateRespondRequest
impl Unpin for RateRespondRequest
impl UnsafeUnpin for RateRespondRequest
impl UnwindSafe for RateRespondRequest