pub struct RateRespondResponse {
pub limit: Option<LikeLimit>,
}Fields
limit: Option<LikeLimit>Trait Implementations
Sourceimpl Clone for RateRespondResponse
impl Clone for RateRespondResponse
Sourcefn clone(&self) -> RateRespondResponse
fn clone(&self) -> RateRespondResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateRespondResponse
impl Debug for RateRespondResponse
Sourceimpl<'de> Deserialize<'de> for RateRespondResponse
impl<'de> Deserialize<'de> for RateRespondResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RateRespondResponse
impl JsonSchema for RateRespondResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RateRespondResponse
impl RefUnwindSafe for RateRespondResponse
impl Send for RateRespondResponse
impl Sync for RateRespondResponse
impl Unpin for RateRespondResponse
impl UnsafeUnpin for RateRespondResponse
impl UnwindSafe for RateRespondResponse