pub struct RecommendationSubject {
pub subject_id: String,
pub rating_token: String,
pub origin: Option<String>,
}Fields
subject_id: Stringrating_token: Stringorigin: Option<String>Trait Implementations
Sourceimpl Clone for RecommendationSubject
impl Clone for RecommendationSubject
Sourcefn clone(&self) -> RecommendationSubject
fn clone(&self) -> RecommendationSubject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecommendationSubject
impl Debug for RecommendationSubject
Sourceimpl<'de> Deserialize<'de> for RecommendationSubject
impl<'de> Deserialize<'de> for RecommendationSubject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecommendationSubject
impl JsonSchema for RecommendationSubject
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecommendationSubject
impl RefUnwindSafe for RecommendationSubject
impl Send for RecommendationSubject
impl Sync for RecommendationSubject
impl Unpin for RecommendationSubject
impl UnsafeUnpin for RecommendationSubject
impl UnwindSafe for RecommendationSubject