pub struct RecommendationsFeed {
pub id: i32,
pub origin: String,
pub subjects: Vec<RecommendationSubject>,
pub permission: Option<String>,
pub preview: Option<RecommendationsPreview>,
}Fields
id: i32origin: Stringsubjects: Vec<RecommendationSubject>permission: Option<String>preview: Option<RecommendationsPreview>Trait Implementations
Sourceimpl Clone for RecommendationsFeed
impl Clone for RecommendationsFeed
Sourcefn clone(&self) -> RecommendationsFeed
fn clone(&self) -> RecommendationsFeed
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecommendationsFeed
impl Debug for RecommendationsFeed
Sourceimpl<'de> Deserialize<'de> for RecommendationsFeed
impl<'de> Deserialize<'de> for RecommendationsFeed
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecommendationsFeed
impl JsonSchema for RecommendationsFeed
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecommendationsFeed
impl RefUnwindSafe for RecommendationsFeed
impl Send for RecommendationsFeed
impl Sync for RecommendationsFeed
impl Unpin for RecommendationsFeed
impl UnsafeUnpin for RecommendationsFeed
impl UnwindSafe for RecommendationsFeed