pub struct RecommendationsPreview {
pub subjects: Vec<RecommendationSubject>,
pub permission: String,
}Fields
subjects: Vec<RecommendationSubject>permission: StringTrait Implementations
Sourceimpl Clone for RecommendationsPreview
impl Clone for RecommendationsPreview
Sourcefn clone(&self) -> RecommendationsPreview
fn clone(&self) -> RecommendationsPreview
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecommendationsPreview
impl Debug for RecommendationsPreview
Sourceimpl<'de> Deserialize<'de> for RecommendationsPreview
impl<'de> Deserialize<'de> for RecommendationsPreview
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecommendationsPreview
impl JsonSchema for RecommendationsPreview
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecommendationsPreview
impl RefUnwindSafe for RecommendationsPreview
impl Send for RecommendationsPreview
impl Sync for RecommendationsPreview
impl Unpin for RecommendationsPreview
impl UnsafeUnpin for RecommendationsPreview
impl UnwindSafe for RecommendationsPreview