pub struct RecommendationsResponse {
pub feeds: Vec<RecommendationsFeed>,
pub active_pills: Option<Vec<ActivePill>>,
pub cache_control: Option<Value>,
}Fields
feeds: Vec<RecommendationsFeed>active_pills: Option<Vec<ActivePill>>cache_control: Option<Value>Trait Implementations
Sourceimpl Clone for RecommendationsResponse
impl Clone for RecommendationsResponse
Sourcefn clone(&self) -> RecommendationsResponse
fn clone(&self) -> RecommendationsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecommendationsResponse
impl Debug for RecommendationsResponse
Sourceimpl<'de> Deserialize<'de> for RecommendationsResponse
impl<'de> Deserialize<'de> for RecommendationsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecommendationsResponse
impl JsonSchema for RecommendationsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecommendationsResponse
impl RefUnwindSafe for RecommendationsResponse
impl Send for RecommendationsResponse
impl Sync for RecommendationsResponse
impl Unpin for RecommendationsResponse
impl UnsafeUnpin for RecommendationsResponse
impl UnwindSafe for RecommendationsResponse