pub struct RecsV2Params {
pub new_here: bool,
pub active_today: bool,
}Fields
new_here: boolactive_today: boolTrait Implementations
Sourceimpl Clone for RecsV2Params
impl Clone for RecsV2Params
Sourcefn clone(&self) -> RecsV2Params
fn clone(&self) -> RecsV2Params
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecsV2Params
impl Debug for RecsV2Params
Sourceimpl Default for RecsV2Params
impl Default for RecsV2Params
Sourcefn default() -> RecsV2Params
fn default() -> RecsV2Params
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RecsV2Params
impl<'de> Deserialize<'de> for RecsV2Params
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecsV2Params
impl JsonSchema for RecsV2Params
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecsV2Params
impl RefUnwindSafe for RecsV2Params
impl Send for RecsV2Params
impl Sync for RecsV2Params
impl Unpin for RecsV2Params
impl UnsafeUnpin for RecsV2Params
impl UnwindSafe for RecsV2Params