pub struct RelationshipTypeIds {
pub value: Vec<RelationshipTypeProfile>,
pub visible: bool,
}Fields
value: Vec<RelationshipTypeProfile>visible: boolTrait Implementations
Sourceimpl Clone for RelationshipTypeIds
impl Clone for RelationshipTypeIds
Sourcefn clone(&self) -> RelationshipTypeIds
fn clone(&self) -> RelationshipTypeIds
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelationshipTypeIds
impl Debug for RelationshipTypeIds
Sourceimpl<'de> Deserialize<'de> for RelationshipTypeIds
impl<'de> Deserialize<'de> for RelationshipTypeIds
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RelationshipTypeIds
impl JsonSchema for RelationshipTypeIds
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelationshipTypeIds
impl RefUnwindSafe for RelationshipTypeIds
impl Send for RelationshipTypeIds
impl Sync for RelationshipTypeIds
impl Unpin for RelationshipTypeIds
impl UnsafeUnpin for RelationshipTypeIds
impl UnwindSafe for RelationshipTypeIds