pub struct Religion {
pub value: Vec<ReligionProfile>,
pub visible: bool,
}Fields
value: Vec<ReligionProfile>visible: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Religion
impl<'de> Deserialize<'de> for Religion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Religion
impl JsonSchema for Religion
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Religion
impl RefUnwindSafe for Religion
impl Send for Religion
impl Sync for Religion
impl Unpin for Religion
impl UnsafeUnpin for Religion
impl UnwindSafe for Religion