pub struct SelfContentResponse {
pub content: ContentData,
}Fields
content: ContentDataTrait Implementations
Sourceimpl Clone for SelfContentResponse
impl Clone for SelfContentResponse
Sourcefn clone(&self) -> SelfContentResponse
fn clone(&self) -> SelfContentResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelfContentResponse
impl Debug for SelfContentResponse
Sourceimpl<'de> Deserialize<'de> for SelfContentResponse
impl<'de> Deserialize<'de> for SelfContentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SelfContentResponse
impl JsonSchema for SelfContentResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SelfContentResponse
impl RefUnwindSafe for SelfContentResponse
impl Send for SelfContentResponse
impl Sync for SelfContentResponse
impl Unpin for SelfContentResponse
impl UnsafeUnpin for SelfContentResponse
impl UnwindSafe for SelfContentResponse