pub struct SelfProfileResponse {
pub user_id: String,
pub created: String,
pub registered: String,
pub modified: String,
pub last_active_opt_in: bool,
pub profile: Profile,
pub paused: bool,
}Fields
user_id: Stringcreated: Stringregistered: Stringmodified: Stringlast_active_opt_in: boolprofile: Profilepaused: boolTrait Implementations
Sourceimpl Clone for SelfProfileResponse
impl Clone for SelfProfileResponse
Sourcefn clone(&self) -> SelfProfileResponse
fn clone(&self) -> SelfProfileResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelfProfileResponse
impl Debug for SelfProfileResponse
Sourceimpl<'de> Deserialize<'de> for SelfProfileResponse
impl<'de> Deserialize<'de> for SelfProfileResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SelfProfileResponse
impl JsonSchema for SelfProfileResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SelfProfileResponse
impl RefUnwindSafe for SelfProfileResponse
impl Send for SelfProfileResponse
impl Sync for SelfProfileResponse
impl Unpin for SelfProfileResponse
impl UnsafeUnpin for SelfProfileResponse
impl UnwindSafe for SelfProfileResponse