pub struct SendMessagePayload {
pub dedup_id: Option<String>,
pub ays: bool,
pub match_message: bool,
pub message_type: String,
pub message_data: MessageData,
pub subject_id: String,
pub origin: String,
}Fields
dedup_id: Option<String>ays: boolmatch_message: boolmessage_type: Stringmessage_data: MessageDatasubject_id: Stringorigin: StringTrait Implementations
Sourceimpl Clone for SendMessagePayload
impl Clone for SendMessagePayload
Sourcefn clone(&self) -> SendMessagePayload
fn clone(&self) -> SendMessagePayload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendMessagePayload
impl Debug for SendMessagePayload
Sourceimpl<'de> Deserialize<'de> for SendMessagePayload
impl<'de> Deserialize<'de> for SendMessagePayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendMessagePayload
impl JsonSchema for SendMessagePayload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendMessagePayload
impl RefUnwindSafe for SendMessagePayload
impl Send for SendMessagePayload
impl Sync for SendMessagePayload
impl Unpin for SendMessagePayload
impl UnsafeUnpin for SendMessagePayload
impl UnwindSafe for SendMessagePayload