pub struct SendbirdChannelHandle {
pub channel_url: String,
}Fields
channel_url: StringTrait Implementations
Sourceimpl Clone for SendbirdChannelHandle
impl Clone for SendbirdChannelHandle
Sourcefn clone(&self) -> SendbirdChannelHandle
fn clone(&self) -> SendbirdChannelHandle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendbirdChannelHandle
impl Debug for SendbirdChannelHandle
Sourceimpl<'de> Deserialize<'de> for SendbirdChannelHandle
impl<'de> Deserialize<'de> for SendbirdChannelHandle
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendbirdChannelHandle
impl JsonSchema for SendbirdChannelHandle
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendbirdChannelHandle
impl RefUnwindSafe for SendbirdChannelHandle
impl Send for SendbirdChannelHandle
impl Sync for SendbirdChannelHandle
impl Unpin for SendbirdChannelHandle
impl UnsafeUnpin for SendbirdChannelHandle
impl UnwindSafe for SendbirdChannelHandle