pub struct SendbirdChannelsInput {
pub limit: Option<i32>,
}Fields
limit: Option<i32>Trait Implementations
Sourceimpl Clone for SendbirdChannelsInput
impl Clone for SendbirdChannelsInput
Sourcefn clone(&self) -> SendbirdChannelsInput
fn clone(&self) -> SendbirdChannelsInput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendbirdChannelsInput
impl Debug for SendbirdChannelsInput
Sourceimpl<'de> Deserialize<'de> for SendbirdChannelsInput
impl<'de> Deserialize<'de> for SendbirdChannelsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendbirdChannelsInput
impl JsonSchema for SendbirdChannelsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendbirdChannelsInput
impl RefUnwindSafe for SendbirdChannelsInput
impl Send for SendbirdChannelsInput
impl Sync for SendbirdChannelsInput
impl Unpin for SendbirdChannelsInput
impl UnsafeUnpin for SendbirdChannelsInput
impl UnwindSafe for SendbirdChannelsInput