pub struct SendbirdChannelsResponse {
pub channels: Vec<SendbirdGroupChannel>,
}Fields
channels: Vec<SendbirdGroupChannel>Trait Implementations
Sourceimpl Clone for SendbirdChannelsResponse
impl Clone for SendbirdChannelsResponse
Sourcefn clone(&self) -> SendbirdChannelsResponse
fn clone(&self) -> SendbirdChannelsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendbirdChannelsResponse
impl Debug for SendbirdChannelsResponse
Sourceimpl<'de> Deserialize<'de> for SendbirdChannelsResponse
impl<'de> Deserialize<'de> for SendbirdChannelsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendbirdChannelsResponse
impl JsonSchema for SendbirdChannelsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendbirdChannelsResponse
impl RefUnwindSafe for SendbirdChannelsResponse
impl Send for SendbirdChannelsResponse
impl Sync for SendbirdChannelsResponse
impl Unpin for SendbirdChannelsResponse
impl UnsafeUnpin for SendbirdChannelsResponse
impl UnwindSafe for SendbirdChannelsResponse