pub struct SendbirdCloseRequest {
pub code: Option<u16>,
pub reason: Option<String>,
}Fields
code: Option<u16>reason: Option<String>Trait Implementations
Sourceimpl Clone for SendbirdCloseRequest
impl Clone for SendbirdCloseRequest
Sourcefn clone(&self) -> SendbirdCloseRequest
fn clone(&self) -> SendbirdCloseRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendbirdCloseRequest
impl Debug for SendbirdCloseRequest
Sourceimpl<'de> Deserialize<'de> for SendbirdCloseRequest
impl<'de> Deserialize<'de> for SendbirdCloseRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendbirdCloseRequest
impl JsonSchema for SendbirdCloseRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendbirdCloseRequest
impl RefUnwindSafe for SendbirdCloseRequest
impl Send for SendbirdCloseRequest
impl Sync for SendbirdCloseRequest
impl Unpin for SendbirdCloseRequest
impl UnsafeUnpin for SendbirdCloseRequest
impl UnwindSafe for SendbirdCloseRequest