pub struct SendbirdMessage {Show 22 fields
pub msg_type: String,
pub message_id: String,
pub message: String,
pub data: String,
pub custom_type: String,
pub file: Value,
pub created_at: String,
pub user: SendbirdMessageUser,
pub channel_url: String,
pub updated_at: String,
pub message_survival_seconds: String,
pub mentioned_users: Vec<Value>,
pub mention_type: String,
pub silent: bool,
pub message_retention_hour: String,
pub channel_type: String,
pub translations: Value,
pub sorted_metaarray: Vec<SendbirdMessageMetaItem>,
pub is_removed: bool,
pub is_op_msg: bool,
pub reactions_summary: Vec<Value>,
pub message_events: Value,
}Fields
msg_type: Stringmessage_id: Stringmessage: Stringdata: Stringcustom_type: Stringfile: Valuecreated_at: Stringuser: SendbirdMessageUserchannel_url: Stringupdated_at: Stringmessage_survival_seconds: Stringmentioned_users: Vec<Value>mention_type: Stringsilent: boolmessage_retention_hour: Stringchannel_type: Stringtranslations: Valuesorted_metaarray: Vec<SendbirdMessageMetaItem>is_removed: boolis_op_msg: boolreactions_summary: Vec<Value>message_events: ValueTrait Implementations
Sourceimpl Clone for SendbirdMessage
impl Clone for SendbirdMessage
Sourcefn clone(&self) -> SendbirdMessage
fn clone(&self) -> SendbirdMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendbirdMessage
impl Debug for SendbirdMessage
Sourceimpl<'de> Deserialize<'de> for SendbirdMessage
impl<'de> Deserialize<'de> for SendbirdMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendbirdMessage
impl JsonSchema for SendbirdMessage
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendbirdMessage
impl RefUnwindSafe for SendbirdMessage
impl Send for SendbirdMessage
impl Sync for SendbirdMessage
impl Unpin for SendbirdMessage
impl UnsafeUnpin for SendbirdMessage
impl UnwindSafe for SendbirdMessage