pub struct SendbirdMessagesResponse {
pub messages: Vec<SendbirdMessage>,
}Fields
messages: Vec<SendbirdMessage>Trait Implementations
Sourceimpl Clone for SendbirdMessagesResponse
impl Clone for SendbirdMessagesResponse
Sourcefn clone(&self) -> SendbirdMessagesResponse
fn clone(&self) -> SendbirdMessagesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendbirdMessagesResponse
impl Debug for SendbirdMessagesResponse
Sourceimpl<'de> Deserialize<'de> for SendbirdMessagesResponse
impl<'de> Deserialize<'de> for SendbirdMessagesResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendbirdMessagesResponse
impl JsonSchema for SendbirdMessagesResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendbirdMessagesResponse
impl RefUnwindSafe for SendbirdMessagesResponse
impl Send for SendbirdMessagesResponse
impl Sync for SendbirdMessagesResponse
impl Unpin for SendbirdMessagesResponse
impl UnsafeUnpin for SendbirdMessagesResponse
impl UnwindSafe for SendbirdMessagesResponse