pub struct SendbirdReadResponse {
pub channel_id: String,
pub user: SendbirdReadUser,
pub ts: String,
pub sts: String,
pub channel_url: String,
pub channel_type: String,
pub is_super: bool,
pub target_parent_message_id: Option<String>,
pub req_id: String,
}Fields
channel_id: Stringuser: SendbirdReadUserts: Stringsts: Stringchannel_url: Stringchannel_type: Stringis_super: booltarget_parent_message_id: Option<String>req_id: StringTrait Implementations
Sourceimpl Clone for SendbirdReadResponse
impl Clone for SendbirdReadResponse
Sourcefn clone(&self) -> SendbirdReadResponse
fn clone(&self) -> SendbirdReadResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendbirdReadResponse
impl Debug for SendbirdReadResponse
Sourceimpl<'de> Deserialize<'de> for SendbirdReadResponse
impl<'de> Deserialize<'de> for SendbirdReadResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendbirdReadResponse
impl JsonSchema for SendbirdReadResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendbirdReadResponse
impl RefUnwindSafe for SendbirdReadResponse
impl Send for SendbirdReadResponse
impl Sync for SendbirdReadResponse
impl Unpin for SendbirdReadResponse
impl UnsafeUnpin for SendbirdReadResponse
impl UnwindSafe for SendbirdReadResponse