pub struct SexualOrientations {
pub value: Vec<i32>,
pub visible: bool,
}Fields
value: Vec<i32>visible: boolTrait Implementations
Sourceimpl Clone for SexualOrientations
impl Clone for SexualOrientations
Sourcefn clone(&self) -> SexualOrientations
fn clone(&self) -> SexualOrientations
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SexualOrientations
impl Debug for SexualOrientations
Sourceimpl<'de> Deserialize<'de> for SexualOrientations
impl<'de> Deserialize<'de> for SexualOrientations
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SexualOrientations
impl JsonSchema for SexualOrientations
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SexualOrientations
impl RefUnwindSafe for SexualOrientations
impl Send for SexualOrientations
impl Sync for SexualOrientations
impl Unpin for SexualOrientations
impl UnsafeUnpin for SexualOrientations
impl UnwindSafe for SexualOrientations