pub struct SkipInput {
pub subject_id: String,
pub rating_token: String,
pub origin: Option<String>,
}Fields
subject_id: Stringrating_token: Stringorigin: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SkipInput
impl<'de> Deserialize<'de> for SkipInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SkipInput
impl JsonSchema for SkipInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SkipInput
impl RefUnwindSafe for SkipInput
impl Send for SkipInput
impl Sync for SkipInput
impl Unpin for SkipInput
impl UnsafeUnpin for SkipInput
impl UnwindSafe for SkipInput