pub struct SortedLikeIdV2 {
pub id: String,
}Fields
id: StringTrait Implementations
Sourceimpl Clone for SortedLikeIdV2
impl Clone for SortedLikeIdV2
Sourcefn clone(&self) -> SortedLikeIdV2
fn clone(&self) -> SortedLikeIdV2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SortedLikeIdV2
impl Debug for SortedLikeIdV2
Sourceimpl<'de> Deserialize<'de> for SortedLikeIdV2
impl<'de> Deserialize<'de> for SortedLikeIdV2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SortedLikeIdV2
impl JsonSchema for SortedLikeIdV2
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SortedLikeIdV2
impl RefUnwindSafe for SortedLikeIdV2
impl Send for SortedLikeIdV2
impl Sync for SortedLikeIdV2
impl Unpin for SortedLikeIdV2
impl UnsafeUnpin for SortedLikeIdV2
impl UnwindSafe for SortedLikeIdV2