pub struct SortedLikesGroupV2 {
pub sort_id: String,
pub data: Vec<SortedLikeIdV2>,
}Fields
sort_id: Stringdata: Vec<SortedLikeIdV2>Trait Implementations
Sourceimpl Clone for SortedLikesGroupV2
impl Clone for SortedLikesGroupV2
Sourcefn clone(&self) -> SortedLikesGroupV2
fn clone(&self) -> SortedLikesGroupV2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SortedLikesGroupV2
impl Debug for SortedLikesGroupV2
Sourceimpl<'de> Deserialize<'de> for SortedLikesGroupV2
impl<'de> Deserialize<'de> for SortedLikesGroupV2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SortedLikesGroupV2
impl JsonSchema for SortedLikesGroupV2
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SortedLikesGroupV2
impl RefUnwindSafe for SortedLikesGroupV2
impl Send for SortedLikesGroupV2
impl Sync for SortedLikesGroupV2
impl Unpin for SortedLikesGroupV2
impl UnsafeUnpin for SortedLikesGroupV2
impl UnwindSafe for SortedLikesGroupV2