pub struct StandoutContent {
pub photo: Option<StandoutMediaRef>,
pub prompt: Option<StandoutMediaRef>,
}Fields
photo: Option<StandoutMediaRef>prompt: Option<StandoutMediaRef>Trait Implementations
Sourceimpl Clone for StandoutContent
impl Clone for StandoutContent
Sourcefn clone(&self) -> StandoutContent
fn clone(&self) -> StandoutContent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StandoutContent
impl Debug for StandoutContent
Sourceimpl<'de> Deserialize<'de> for StandoutContent
impl<'de> Deserialize<'de> for StandoutContent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StandoutContent
impl JsonSchema for StandoutContent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StandoutContent
impl RefUnwindSafe for StandoutContent
impl Send for StandoutContent
impl Sync for StandoutContent
impl Unpin for StandoutContent
impl UnsafeUnpin for StandoutContent
impl UnwindSafe for StandoutContent