pub struct StandoutItem {
pub subject_id: String,
pub rating_token: String,
pub content: StandoutContent,
}Fields
subject_id: Stringrating_token: Stringcontent: StandoutContentTrait Implementations
Sourceimpl Clone for StandoutItem
impl Clone for StandoutItem
Sourcefn clone(&self) -> StandoutItem
fn clone(&self) -> StandoutItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StandoutItem
impl Debug for StandoutItem
Sourceimpl<'de> Deserialize<'de> for StandoutItem
impl<'de> Deserialize<'de> for StandoutItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StandoutItem
impl JsonSchema for StandoutItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StandoutItem
impl RefUnwindSafe for StandoutItem
impl Send for StandoutItem
impl Sync for StandoutItem
impl Unpin for StandoutItem
impl UnsafeUnpin for StandoutItem
impl UnwindSafe for StandoutItem