pub struct StandoutMediaRef {
pub content_id: String,
}Fields
content_id: StringTrait Implementations
Sourceimpl Clone for StandoutMediaRef
impl Clone for StandoutMediaRef
Sourcefn clone(&self) -> StandoutMediaRef
fn clone(&self) -> StandoutMediaRef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StandoutMediaRef
impl Debug for StandoutMediaRef
Sourceimpl<'de> Deserialize<'de> for StandoutMediaRef
impl<'de> Deserialize<'de> for StandoutMediaRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StandoutMediaRef
impl JsonSchema for StandoutMediaRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StandoutMediaRef
impl RefUnwindSafe for StandoutMediaRef
impl Send for StandoutMediaRef
impl Sync for StandoutMediaRef
impl Unpin for StandoutMediaRef
impl UnsafeUnpin for StandoutMediaRef
impl UnwindSafe for StandoutMediaRef