pub struct StandoutsResponse {
pub status: String,
pub expiration: Option<String>,
pub standouts: Vec<StandoutItem>,
}Fields
status: Stringexpiration: Option<String>standouts: Vec<StandoutItem>Trait Implementations
Sourceimpl Clone for StandoutsResponse
impl Clone for StandoutsResponse
Sourcefn clone(&self) -> StandoutsResponse
fn clone(&self) -> StandoutsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StandoutsResponse
impl Debug for StandoutsResponse
Sourceimpl<'de> Deserialize<'de> for StandoutsResponse
impl<'de> Deserialize<'de> for StandoutsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StandoutsResponse
impl JsonSchema for StandoutsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StandoutsResponse
impl RefUnwindSafe for StandoutsResponse
impl Send for StandoutsResponse
impl Sync for StandoutsResponse
impl Unpin for StandoutsResponse
impl UnsafeUnpin for StandoutsResponse
impl UnwindSafe for StandoutsResponse