pub struct VideoPrompt {
pub content_id: String,
pub question_id: String,
pub thumbnail_url: String,
pub video_url: String,
pub cdn_id: String,
pub bounding_box: BoundingBox,
}Fields
content_id: Stringquestion_id: Stringthumbnail_url: Stringvideo_url: Stringcdn_id: Stringbounding_box: BoundingBoxTrait Implementations
Sourceimpl Clone for VideoPrompt
impl Clone for VideoPrompt
Sourcefn clone(&self) -> VideoPrompt
fn clone(&self) -> VideoPrompt
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VideoPrompt
impl Debug for VideoPrompt
Sourceimpl<'de> Deserialize<'de> for VideoPrompt
impl<'de> Deserialize<'de> for VideoPrompt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VideoPrompt
impl JsonSchema for VideoPrompt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VideoPrompt
impl RefUnwindSafe for VideoPrompt
impl Send for VideoPrompt
impl Sync for VideoPrompt
impl Unpin for VideoPrompt
impl UnsafeUnpin for VideoPrompt
impl UnwindSafe for VideoPrompt