pub struct VoiceAnswerPayload {
pub cdn_url: String,
pub waveform: String,
pub answer_type: String,
pub cdn_id: String,
pub url: String,
}Fields
cdn_url: Stringwaveform: Stringanswer_type: Stringcdn_id: Stringurl: StringTrait Implementations
Sourceimpl Clone for VoiceAnswerPayload
impl Clone for VoiceAnswerPayload
Sourcefn clone(&self) -> VoiceAnswerPayload
fn clone(&self) -> VoiceAnswerPayload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VoiceAnswerPayload
impl Debug for VoiceAnswerPayload
Sourceimpl<'de> Deserialize<'de> for VoiceAnswerPayload
impl<'de> Deserialize<'de> for VoiceAnswerPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VoiceAnswerPayload
impl JsonSchema for VoiceAnswerPayload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VoiceAnswerPayload
impl RefUnwindSafe for VoiceAnswerPayload
impl Send for VoiceAnswerPayload
impl Sync for VoiceAnswerPayload
impl Unpin for VoiceAnswerPayload
impl UnsafeUnpin for VoiceAnswerPayload
impl UnwindSafe for VoiceAnswerPayload