Module containing serializers for API format (numeric enums)
Functions
- serialize_
enum - Serialize an enum to its numeric value for the API
- serialize_
option_ enum - Serialize an optional enum to its numeric value for the API
- serialize_
vec_ enum - Serialize a vector of enums to their numeric values for the API